@@ -1,5 +1,5 @@
 ;Liquid War 6 is a unique multiplayer wargame.
-;Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+;Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 ;
 ;This program is free software; you can redistribute it and/or modify
 ;it under the terms of the GNU General Public License as published by
@@ -21,10 +21,10 @@
 (define lw6-clear
   (lambda () 
     (begin
-      (lw6-set-game-global! "map-source" #f)
-      (lw6-set-game-global! "map-instance" #f)
+      (lw6-purge-menu-stack)
+      (lw6-purge-game-globals)
       (flush-all-ports)
       (gc)
       )
     )
-  )
\ No newline at end of file
+  )
