@@ -18,6 +18,14 @@
 ;Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
 ;Contact author        : ufoot@ufoot.org
 
+(define lw6-loader-purge
+  (lambda ()
+    (begin
+      (lw6-game-param-update)
+      (map (lambda (key)
+	     (lw6-set-game-global! key #f))
+	   (list "loaded" "level" "game-state" "pilot")))))
+      
 (define lw6-loader-push
   (lambda (relative-path) 
     (let* (
@@ -29,7 +37,9 @@
 	   (video-mode (c-lw6dsp-get-video-mode dsp))
 	   (width (assoc-ref video-mode "width"))
 	   (height (assoc-ref video-mode "height"))
-	   (bench-value (lw6-config-get-number lw6def-bench-value))
+	   (bench-value (min 
+			 (lw6-config-get-number lw6def-bench-value)
+			 (lw6-config-get-number lw6def-max-local-bench-value)))
 	   (magic-number (lw6-config-get-number lw6def-magic-number))
 	  )
       (begin
