@@ -65,7 +65,14 @@
       (lw6-menu-action menu "on-push") 
       (lw6-menu-update-selected-item menu)
       (lw6-menu-sync menu)
-      (lw6-menuitem-action (lw6-current-menuitem) "on-select")
+      (c-lw6gui-menu-set-breadcrumbs (assoc-ref menu "smob") (lw6-menu-breadcrumbs))
+      (let (
+	    (menuitem (lw6-current-menuitem))
+	    )
+	(if (assoc-ref menuitem "enabled")
+	    (lw6-menuitem-action menuitem "on-select")
+	    )
+	)
       ;;(lw6-menu-center)
       )))
 
@@ -81,6 +88,7 @@
     (begin
       (lw6-menu-action menu "on-pop")
       (lw6-pop-menu-raw)
+      (c-lw6gui-menu-set-breadcrumbs (assoc-ref menu "smob") (lw6-menu-breadcrumbs))
       (lw6-menu-action (lw6-current-menu) "on-pop-child")
       (let (
 	    (menu (lw6-current-menu))
@@ -118,6 +126,25 @@
 	  (lw6-menu-has-items? menu)
 	  #f))))
 
+(define lw6-menu-has-popup?
+  (lambda ()
+    (let* (
+	   (menu (lw6-current-menu))
+	   (menu-smob (if menu (assoc-ref menu "smob") #f))
+	   )
+      (if menu 
+	  (c-lw6gui-menu-has-popup menu-smob)
+	  #f))))	  
+
+(define lw6-menu-close-popup
+  (lambda ()
+    (let* (
+	   (menu (lw6-current-menu))
+	   (menu-smob (if menu (assoc-ref menu "smob") #f))
+	   )
+      (if menu 
+	  (c-lw6gui-menu-close-popup menu-smob)))))
+
 (define lw6-current-menuitem
   (lambda ()
     (let* (
@@ -144,12 +171,20 @@
 	    (if (= selected-item new-selected-item)
 		#f
 		(begin
-		  (lw6-play-fx-beep-select)
 		  (lw6-menuitem-action menuitem "on-unselect")
 		  (assoc-set! menu "selected-item" new-selected-item)
 		  (assoc-set! menu "allow-scroll" allow-scroll)
 		  (lw6-menu-sync menu)
-		  (lw6-menuitem-action (lw6-current-menuitem) "on-select")
+		  (let (
+			(menuitem (lw6-current-menuitem))
+			)
+		    (if (assoc-ref menuitem "enabled")
+			(begin
+			  (lw6-play-fx-beep-select)
+			  (lw6-menuitem-action menuitem "on-select")
+			  )
+			)
+		    )
 					;(if warp-mouse (lw6-menu-warp-mouse))
 		  #t
 		  )))))))
@@ -187,11 +222,14 @@
 	#f )))
 
 (define lw6-menu-template
-  (lambda (title)
+  (lambda (title help popup)
     (list
      (cons "smob" (c-lw6gui-menu-new title 
+				     help
+				     popup
 				     (_ "Esc") 
 				     (lw6-config-is-true? lw6def-use-esc-button)))
+     (cons "title" title)
      (cons "selected-item" 0)
      (cons "allow-scroll" #f)
      (cons "items" (list))
@@ -203,9 +241,10 @@
      (cons "on-display" (lambda (m) #t)))))
 
 (define lw6-menu-item-template
-  (lambda (label)
+  (lambda (label tooltip)
     (let (
-	  (menuitem (list (cons "label" label)))
+	  (menuitem (list (cons "label" label) 
+			  (cons "tooltip" tooltip)))
 	  )
       (begin
 	(set! menuitem (lw6-menu-item-template-update menuitem))
@@ -327,31 +366,40 @@
       )))
 
 (define lw6-menu-item-list-template
-  (lambda (label-func update-func index-func values-list)
-    (lw6-menu-item-list-template-update (list) label-func update-func index-func values-list)))
+  (lambda (label-func update-func index-func values-list tooltip)
+    (let (
+	  (menu-item (list))
+)
+      (begin
+	(set! menu-item (lw6-menu-item-list-template-update menu-item label-func update-func index-func values-list))
+	(set! menu-item (assoc-set! menu-item "tooltip" tooltip))
+	menu-item
+	))))
 
 (define lw6-menu-item-list-number-template
-  (lambda (config-key labels)
+  (lambda (config-key labels tooltip)
     (lw6-menu-item-list-template 
      lw6-menu-item-list-label-func
      (lw6-menu-item-list-number-update-func config-key)
      (lw6-menu-item-list-number-index-func config-key)
      labels
+     tooltip
      )))
 
 (define lw6-menu-item-list-boolean-template
-  (lambda (config-key label-true label-false)
+  (lambda (config-key label-true label-false tooltip)
     (lw6-menu-item-list-template 
      lw6-menu-item-list-label-func
      (lw6-menu-item-list-boolean-update-func config-key)
      (lw6-menu-item-list-boolean-index-func config-key)
      (list label-false label-true)
+     tooltip
      )))
 
 (define lw6-menu-item-template-switch
-  (lambda (label-func on-plus on-minus)
+  (lambda (label-func on-plus on-minus tooltip)
     (let (
-	  (item (lw6-menu-item-template (label-func)))
+	  (item (lw6-menu-item-template (label-func) tooltip))
 	  )
       (begin
 	(assoc-set! item "on-valid" 
@@ -391,11 +439,12 @@
 
 (define lw6-menu-pump-buttons
   (lambda ()
-    (let
+    (let*
 	(
 	 (dsp (lw6-get-game-global "dsp"))
 	 (menu (lw6-current-menu))
 	 (menuitem (lw6-current-menuitem))
+	 (enabled (if menuitem (assoc-ref menuitem "enabled") #f))
 	 )
       (if
        menu
@@ -419,13 +468,17 @@
 		    (c-lw6gui-joystick2-pop-pad-up dsp))
 		   (if
 		    (lw6-prev-menuitem #f)
-		    (lw6-play-fx-beep-select)
+		    (if (assoc-ref (lw6-current-menuitem) "enabled")
+			(lw6-play-fx-beep-select)
+			)
 		    )
 		   )
 		  ((c-lw6gui-mouse-pop-wheel-up dsp)
 		   (if
 		    (lw6-prev-menuitem #t)
-		    (lw6-play-fx-beep-select)
+		    (if (assoc-ref (lw6-current-menuitem) "enabled")
+			(lw6-play-fx-beep-select)
+			)
 		    )
 		   )
 		  ((or
@@ -434,45 +487,68 @@
 		    (c-lw6gui-joystick2-pop-pad-down dsp))
 		   (if
 		    (lw6-next-menuitem #f)
-		    (lw6-play-fx-beep-select)
+		    (if (assoc-ref (lw6-current-menuitem) "enabled")
+			(lw6-play-fx-beep-select)
+			)
 		    )
 		   )
 		  ((c-lw6gui-mouse-pop-wheel-down dsp)
 		   (if
 		    (lw6-next-menuitem #t)
-		    (lw6-play-fx-beep-select)
+		    (if (assoc-ref (lw6-current-menuitem) "enabled")
+			(lw6-play-fx-beep-select)
+			)
 		    )
 		   )
 		  ((or
 		    (c-lw6gui-keyboard-pop-arrow-left dsp)
 		    (c-lw6gui-joystick1-pop-pad-left dsp)
 		    (c-lw6gui-joystick2-pop-pad-left dsp))
-		   (if
-		    (lw6-menuitem-action menuitem "on-minus")
-		    (lw6-play-fx-beep-valid)
-		    ) 
+		   (if enabled 
+		       (if
+			(lw6-menuitem-action menuitem "on-minus")
+			(lw6-play-fx-beep-valid)
+			(lw6-play-fx-beep-no)
+			)
+		       (lw6-play-fx-beep-no)
+		       )
 		   )
 		  ((or
 		    (c-lw6gui-keyboard-pop-arrow-right dsp)
 		    (c-lw6gui-joystick1-pop-pad-right dsp)
 		    (c-lw6gui-joystick2-pop-pad-right dsp))
-		   (if
-		    (lw6-menuitem-action menuitem "on-plus")
-		    (lw6-play-fx-beep-valid)
-		    ) 
+		   (if enabled
+		       (if
+			(lw6-menuitem-action menuitem "on-plus")
+			(lw6-play-fx-beep-valid)
+			(lw6-play-fx-beep-no)
+			)
+		       (lw6-play-fx-beep-no)
+		       )
 		   )
 		  ((or
 		    (c-lw6gui-keyboard-pop-key-enter dsp)
 		    (c-lw6gui-joystick1-pop-button-a dsp)
 		    (c-lw6gui-joystick2-pop-button-a dsp))
-		   (if
-		    (lw6-menuitem-action menuitem "on-valid")
-		    (lw6-play-fx-beep-valid)
-		    )
+		   (if enabled
+		       (if
+			(lw6-menuitem-action menuitem "on-valid")
+			(lw6-play-fx-beep-valid)
+			(lw6-play-fx-beep-no)
+			)
+		       (if menuitem
+			   (lw6-play-fx-beep-no)
+			   (begin
+			     (lw6-menu-action menu "on-cancel")
+			     (lw6-play-fx-beep-valid)
+			     )
+			   ))
 		   )
 		  ((c-lw6gui-mouse-pop-button-right dsp)
-		   (lw6-menu-action menu "on-cancel")
-		   (lw6-play-fx-beep-valid)
+		   (begin
+		     (lw6-menu-action menu "on-cancel")
+		     (lw6-play-fx-beep-valid)
+		     )
 		   )
 		  )))
 	   (cond
@@ -497,9 +573,22 @@
 		   (begin
 		     (lw6-set-menuitem! menu-position #f)
 		     (set! menuitem (lw6-current-menuitem))
-		     (if
-		      (lw6-menuitem-action menuitem "on-valid")
-		      (lw6-play-fx-beep-valid))))))
+		     (if (assoc-ref menuitem "enabled") 
+			 (if
+			  (lw6-menuitem-action menuitem "on-valid")
+			  (lw6-play-fx-beep-valid)
+			  (lw6-play-fx-beep-no)
+			  )
+			 (if menuitem
+			     (lw6-play-fx-beep-no)
+			     (begin
+			       (lw6-menu-action menu "on-cancel")
+			       (lw6-play-fx-beep-valid)
+			     )
+			     ))
+		     ))
+	       )	     
+	     )	    
 	    ((> menu-scroll 0)
 	     (begin
 	       (c-lw6gui-mouse-pop-simple-click dsp)
@@ -572,14 +661,29 @@
 		(c-lw6gui-menu-select-esc menu-smob menu-esc)))	       
 	  ))))
 
+(define lw6-menu-breadcrumbs
+  (lambda ()
+    (let (
+	  (menu-stack %lw6-menu-stack)
+	  )
+      (reverse
+       (map (lambda (menuitem) 
+	      (assoc-ref menuitem "title")) 
+	    menu-stack)
+       ))))
+
 (define lw6-menu
   (lambda () 
     (begin 
       (if (lw6-empty-menu-stack?)
 	  (c-lw6sys-signal-send-quit)
 	  )
-      (lw6-menu-pump-buttons)
-      (lw6-menu-pump-mouse)
-      (if (not (lw6-menu-pump-all?))
-	  (lw6-zoom-pump))
+      (if (lw6-menu-has-popup?)
+	  (if (lw6-wait-is-any-key-pressed?)
+	      (lw6-menu-close-popup))
+	  (begin
+	    (lw6-menu-pump-buttons)
+	    (lw6-menu-pump-mouse)
+	    (if (not (lw6-menu-pump-all?))
+		(lw6-zoom-pump))))
       )))
