@@ -33,9 +33,21 @@
 	   (label (if player-status
 		      player-name
 		      (_ "Free slot")))
+	   (tooltip (if player-status
+			(format #f
+				"~a: ~a~%~a: ~a~%~a: ~a"
+				(_ "Name")
+				player-name
+				(_ "Color")
+				player-color
+				(_ "Control")
+				player-control
+				)
+			(_ "You can create a new player here")))
 	   )
       (begin
 	(set! menuitem (assoc-set! menuitem "label" label))
+	(set! menuitem (assoc-set! menuitem "tooltip" tooltip))
 	(set! menuitem (assoc-set! menuitem "on-valid" (lambda (mi) (lw6-push-menu (lw6-player-detail-menu player-prefix)))))
 	(set! menuitem (assoc-set! menuitem "value" (c-lw6map-team-color-key-to-index player-color)))
 	(set! menuitem (assoc-set! menuitem "colored" player-status))
@@ -45,7 +57,7 @@
 (define lw6-players-menu-player-item
   (lambda (player-prefix)
     (let* (
-	   (item (lw6-menu-item-template ""))
+	   (item (lw6-menu-item-template "" #f))
 	  )
       (begin
 	(set! item (assoc-set! item "player-prefix" player-prefix))
@@ -78,7 +90,11 @@
 				      (_ "One bot"))
 				     (map
 				      (lambda (n) (format #f (_ "~a bots") n))
-				      (list 2 3 4 5 6 7 8 9)))))
+				      (list 2 3 4 5 6 7 8 9))
+				     )
+				    (format #f
+					    (_ "Put up to ~a bots on your map")
+					    9)))
 	  )
       (begin
 	item
@@ -87,7 +103,9 @@
 (define lw6-players-menu
   (lambda()
     (let (
-	  (menu (lw6-menu-template (_ "Players")))
+	  (menu (lw6-menu-template (_ "Players")
+				   (_ "Change player options")
+				   #f))
 	  )
       (begin
 	(lw6-append-menuitem! menu (lw6-players-menu-player-item "player1"))	
