@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,19 +38,26 @@ new_target (_mod_idiot_context_t * idiot_context, lw6bot_data_t * data)
   int i = 0;
   int found = 0;
   int fighter_id = -1;
-  lw6ker_fighter_t *fighter;
+  lw6ker_fighter_t *fighter = NULL;
+  lw6sys_whd_t shape = { 0, 0, 0 };
+  lw6ker_cursor_t cursor;
 
-  if (lw6ker_game_state_get_cursor_info
-      (data->game_state, data->param.cursor_id, NULL,
-       NULL, &team_color, &x, &y))
+  if (lw6ker_game_state_get_cursor
+      (data->game_state, &cursor, data->param.cursor_id))
     {
+      x = cursor.pos.x;
+      y = cursor.pos.y;
+      team_color = cursor.team_color;
+
+      lw6ker_game_state_get_shape (data->game_state, &shape);
+
       idiot_context->start_pos_x = x;
       idiot_context->start_pos_y = y;
 
       for (i = 0; i < _MOD_IDIOT_NB_RETRIES && !found; ++i)
 	{
-	  x = lw6sys_random (data->game_state->map_state.shape.w);
-	  y = lw6sys_random (data->game_state->map_state.shape.h);
+	  x = lw6sys_random (shape.w);
+	  y = lw6sys_random (shape.h);
 	  idiot_context->target_pos_x = x;
 	  idiot_context->target_pos_y = y;
 	  if (data->param.iq >= _MOD_IDIOT_IQ_LIMIT1
@@ -58,25 +65,22 @@ new_target (_mod_idiot_context_t * idiot_context, lw6bot_data_t * data)
 	    {
 	      // here, we don't search anymore, just choose random
 	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _
-			  ("idiot bot acting randomly, choosed %d,%d"),
-			  fighter->team_color, x, y);
+			  _x_
+			  ("idiot bot acting randomly, choosed %d,%d"), x, y);
 	      found = 1;
 	    }
 	  else
 	    {
-	      for (z = 0;
-		   z < data->game_state->map_state.shape.d && !found; ++z)
+	      for (z = 0; z < shape.d && !found; ++z)
 		{
 		  fighter_id =
-		    lw6ker_map_state_get_fighter_id (&
-						     (data->game_state->
-						      map_state), x, y, z);
+		    lw6ker_game_state_get_fighter_id (data->game_state, x, y,
+						      z);
 		  if (fighter_id >= 0)
 		    {
 		      fighter =
-			&(data->game_state->map_state.
-			  armies.fighters[fighter_id]);
+			lw6ker_game_state_get_fighter_by_id (data->game_state,
+							     fighter_id);
 		      if (fighter != NULL)
 			{
 			  if (data->param.iq >= _MOD_IDIOT_IQ_LIMIT2
@@ -84,7 +88,7 @@ new_target (_mod_idiot_context_t * idiot_context, lw6bot_data_t * data)
 			    {
 			      // default behavior, find an opponent
 			      lw6sys_log (LW6SYS_LOG_DEBUG,
-					  _
+					  _x_
 					  ("idiot bot acting normally, choosed opponent of color %d at %d,%d"),
 					  fighter->team_color, x, y);
 			      found = 1;
@@ -94,7 +98,7 @@ new_target (_mod_idiot_context_t * idiot_context, lw6bot_data_t * data)
 			    {
 			      // acting stupid, centering on self
 			      lw6sys_log (LW6SYS_LOG_DEBUG,
-					  _
+					  _x_
 					  ("idiot bot acting stupid, choosed self color %d at %d,%d"),
 					  fighter->team_color, x, y);
 			      found = 1;
@@ -105,13 +109,13 @@ new_target (_mod_idiot_context_t * idiot_context, lw6bot_data_t * data)
 	      if (!found)
 		{
 		  lw6sys_log (LW6SYS_LOG_DEBUG,
-			      _("idiot bot found nothing at %d,%d"), x, y);
+			      _x_ ("idiot bot found nothing at %d,%d"), x, y);
 		}
 	    }
 	}
 
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("idiot bot moved start=%d,%d target=%d,%d after %d tries"),
 		  idiot_context->start_pos_x, idiot_context->start_pos_y,
 		  idiot_context->target_pos_x, idiot_context->target_pos_y,
@@ -134,15 +138,15 @@ _mod_idiot_next_move (_mod_idiot_context_t * idiot_context, int *x, int *y,
   int dt = 0;
   int start_of_move;
   int end_of_move;
-  int end_of_wait;
   float average_size = 0.0f;
+  lw6sys_whd_t shape = { 0, 0, 0 };
+
+  lw6ker_game_state_get_shape (data->game_state, &shape);
 
   rounds = lw6ker_game_state_get_rounds (data->game_state);
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("idiot bot move rounds=%d"), rounds);
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("idiot bot move rounds=%d"), rounds);
 
-  average_size =
-    (data->game_state->map_state.shape.w +
-     data->game_state->map_state.shape.h) / 2.0f;
+  average_size = (shape.w + shape.h) / 2.0f;
   d_move =
     lw6sys_max (1,
 		(((float) _MOD_IDIOT_DEFAULT_MOVE_ROUNDS) * average_size) /
@@ -167,7 +171,6 @@ _mod_idiot_next_move (_mod_idiot_context_t * idiot_context, int *x, int *y,
 
   start_of_move = idiot_context->last_move_round;
   end_of_move = start_of_move + d_move;
-  end_of_wait = end_of_move + d_wait;
 
   if (rounds > start_of_move && rounds < end_of_move)
     {
