@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ _mod_idiot_repr (_mod_idiot_context_t * idiot_context, u_int32_t id)
   char *ret = NULL;
 
   ret =
-    lw6sys_new_sprintf (_("%u idiot target=%d,%d"), id,
+    lw6sys_new_sprintf (_x_ ("%u idiot target=%d,%d"), id,
 			(int) idiot_context->target_pos_x,
 			(int) idiot_context->target_pos_y);
 
