@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ load_callback (void *callback_data, char *element, char *key, char *value)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _("option \"%s\" not loaded"), key);
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("option \"%s\" not loaded"), key);
     }
 }
 
@@ -52,7 +52,7 @@ _lw6cfg_load (_lw6cfg_context_t * cfg_context, char *filename)
 {
   int ret = 0;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _("loading config from \"%s\""), filename);
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("loading config from \"%s\""), filename);
 
   if (lw6sys_file_exists (filename))
     {
@@ -63,7 +63,7 @@ _lw6cfg_load (_lw6cfg_context_t * cfg_context, char *filename)
   else
     {
       lw6sys_log (LW6SYS_LOG_INFO,
-		  _("config file \"%s\" doesn't exist, using defaults"),
+		  _x_ ("config file \"%s\" doesn't exist, using defaults"),
 		  filename);
     }
 
