@@ -42,6 +42,9 @@ typedef struct _mod_gl_hud_floating_const_data_s
   float gauge_relative_percent_only_y1;
   float gauge_relative_percent_y1;
   float gauge_relative_frags_y1;
+  int gauge_heartbeat_period;
+  float gauge_relative_heartbeat_min;
+  float gauge_relative_heartbeat_max;
   int gauge_slices;
   int gauge_loops;
   float gauge_start;
@@ -49,6 +52,8 @@ typedef struct _mod_gl_hud_floating_const_data_s
   float gauge_min_size;
   float gauge_max_size;
   float gauge_max_health_angle;
+  float weapon_ambiance_alpha1;
+  float weapon_ambiance_alpha2;
   int score_pie_rotation_period;
   int score_pie_heartbeat_period;
   float score_pie_heartbeat_factor1;
@@ -128,6 +133,14 @@ extern int _mod_gl_hud_floating_context_init (mod_gl_utils_context_t *
 					      utils_context,
 					      _mod_gl_hud_floating_context_t
 					      * floating_context);
+extern int _mod_gl_hud_floating_context_begin_hud (mod_gl_utils_context_t *
+						   utils_context,
+						   _mod_gl_hud_floating_context_t
+						   * floating_context);
+extern void _mod_gl_hud_floating_context_end_hud (mod_gl_utils_context_t *
+						  utils_context,
+						  _mod_gl_hud_floating_context_t
+						  * floating_context);
 extern int _mod_gl_hud_floating_context_update_hud (mod_gl_utils_context_t *
 						    utils_context,
 						    _mod_gl_hud_floating_context_t
@@ -137,6 +150,14 @@ extern int _mod_gl_hud_floating_context_update_hud (mod_gl_utils_context_t *
 						    game_state,
 						    lw6pil_local_cursors_t *
 						    local_cursors);
+extern int _mod_gl_hud_floating_context_begin_score (mod_gl_utils_context_t *
+						     utils_context,
+						     _mod_gl_hud_floating_context_t
+						     * floating_context);
+extern void _mod_gl_hud_floating_context_end_score (mod_gl_utils_context_t *
+						    utils_context,
+						    _mod_gl_hud_floating_context_t
+						    * floating_context);
 extern int _mod_gl_hud_floating_context_update_score (mod_gl_utils_context_t *
 						      utils_context,
 						      _mod_gl_hud_floating_context_t
