@@ -51,11 +51,41 @@ typedef struct _mod_gl_menu_cylinder_const_data_s
   float esc_cyl_height;
   float esc_cyl_height_offset;
   float esc_rotate;
+  float tooltip_alpha_bg;
+  int tooltip_max_width;
+  int tooltip_max_height;
+  int tooltip_border_size;
+  int tooltip_margin_size;
+  int tooltip_reformat_width;
+  float tooltip_relative_size;
+  float help_alpha_bg;
+  int help_max_width;
+  int help_max_height;
+  int help_border_size;
+  int help_margin_size;
+  int help_reformat_width;
+  float help_relative_size;
+  float breadcrumbs_alpha_bg;
+  int breadcrumbs_max_width;
+  int breadcrumbs_max_height;
+  int breadcrumbs_border_size;
+  int breadcrumbs_margin_size;
+  int breadcrumbs_reformat_width;
+  float breadcrumbs_relative_size;
+  float popup_alpha_bg;
+  int popup_max_width;
+  int popup_max_height;
+  int popup_border_size;
+  int popup_margin_size;
+  int popup_reformat_width;
+  float popup_relative_size;
 }
 _mod_gl_menu_cylinder_const_data_t;
 
 typedef struct _mod_gl_menu_cylinder_context_s
 {
+  int i_right_point;
+  int j_tooltip;
   _mod_gl_menu_cylinder_const_data_t const_data;
 }
 _mod_gl_menu_cylinder_context_t;
@@ -85,6 +115,12 @@ extern void _mod_gl_menu_cylinder_display_progress (mod_gl_utils_context_t *
 						    * cylinder_context,
 						    lw6gui_look_t * look,
 						    float progress);
+extern void _mod_gl_menu_cylinder_display_meta (mod_gl_utils_context_t *
+						utils_context,
+						_mod_gl_menu_cylinder_context_t
+						* cylinder_context,
+						lw6gui_look_t * look,
+						lw6gui_menu_t * menu);
 
 /*
  * In data.c
@@ -166,6 +202,15 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
 				 int *position, int *scroll, int *esc,
 				 lw6gui_menu_t * menu, int screen_x,
 				 int screen_y);
+extern void
+_mod_gl_menu_cylinder_get_cylinder_right_point (mod_gl_utils_context_t *
+						utils_context,
+						_mod_gl_menu_cylinder_context_t
+						* cylinder_context, int i,
+						int n,
+						float relative_text_width,
+						float *right_point_x,
+						float *right_point_y);
 
 /*
  * In progress.c
