@@ -156,25 +156,25 @@ key_down (lw6gui_keyboard_t * keyboard, SDL_Event * event,
       sym == const_data->keysym2_up ||
       sym == const_data->keysym3_up || sym == const_data->keysym4_up)
     {
-      lw6gui_button_register_down (&(keyboard->key_up), timestamp);
+      lw6gui_button_register_down (&(keyboard->arrow_up), timestamp);
     }
   if (sym == const_data->keysym1_down ||
       sym == const_data->keysym2_down ||
       sym == const_data->keysym3_down || sym == const_data->keysym4_down)
     {
-      lw6gui_button_register_down (&(keyboard->key_down), timestamp);
+      lw6gui_button_register_down (&(keyboard->arrow_down), timestamp);
     }
   if (sym == const_data->keysym1_left ||
       sym == const_data->keysym2_left ||
       sym == const_data->keysym3_left || sym == const_data->keysym4_left)
     {
-      lw6gui_button_register_down (&(keyboard->key_left), timestamp);
+      lw6gui_button_register_down (&(keyboard->arrow_left), timestamp);
     }
   if (sym == const_data->keysym1_right ||
       sym == const_data->keysym2_right ||
       sym == const_data->keysym3_right || sym == const_data->keysym4_right)
     {
-      lw6gui_button_register_down (&(keyboard->key_right), timestamp);
+      lw6gui_button_register_down (&(keyboard->arrow_right), timestamp);
     }
   if (sym == const_data->keysym1_enter || sym == const_data->keysym2_enter)
     {
@@ -184,6 +184,14 @@ key_down (lw6gui_keyboard_t * keyboard, SDL_Event * event,
     {
       lw6gui_button_register_down (&(keyboard->key_esc), timestamp);
     }
+  if (sym == const_data->keysym1_ctrl || sym == const_data->keysym2_ctrl)
+    {
+      lw6gui_button_register_down (&(keyboard->key_ctrl), timestamp);
+    }
+  if (sym == const_data->keysym1_alt || sym == const_data->keysym2_alt)
+    {
+      lw6gui_button_register_down (&(keyboard->key_alt), timestamp);
+    }
   if (sym == const_data->keysym1_pgup || sym == const_data->keysym2_pgup)
     {
       lw6gui_button_register_down (&(keyboard->key_pgup), timestamp);
@@ -213,7 +221,7 @@ key_up (lw6gui_keyboard_t * keyboard, SDL_Event * event,
 	  && !lw6gui_keyboard_is_pressed (keyboard, const_data->keysym3_up)
 	  && !lw6gui_keyboard_is_pressed (keyboard, const_data->keysym4_up))
 	{
-	  lw6gui_button_register_up (&(keyboard->key_up));
+	  lw6gui_button_register_up (&(keyboard->arrow_up));
 	}
     }
   if (sym == const_data->keysym1_down ||
@@ -225,7 +233,7 @@ key_up (lw6gui_keyboard_t * keyboard, SDL_Event * event,
 	  && !lw6gui_keyboard_is_pressed (keyboard, const_data->keysym3_down)
 	  && !lw6gui_keyboard_is_pressed (keyboard, const_data->keysym4_down))
 	{
-	  lw6gui_button_register_up (&(keyboard->key_down));
+	  lw6gui_button_register_up (&(keyboard->arrow_down));
 	}
     }
   if (sym == const_data->keysym1_left ||
@@ -237,7 +245,7 @@ key_up (lw6gui_keyboard_t * keyboard, SDL_Event * event,
 	  && !lw6gui_keyboard_is_pressed (keyboard, const_data->keysym3_left)
 	  && !lw6gui_keyboard_is_pressed (keyboard, const_data->keysym4_left))
 	{
-	  lw6gui_button_register_up (&(keyboard->key_left));
+	  lw6gui_button_register_up (&(keyboard->arrow_left));
 	}
     }
   if (sym == const_data->keysym1_right ||
@@ -250,7 +258,7 @@ key_up (lw6gui_keyboard_t * keyboard, SDL_Event * event,
 	  && !lw6gui_keyboard_is_pressed (keyboard,
 					  const_data->keysym4_right))
 	{
-	  lw6gui_button_register_up (&(keyboard->key_right));
+	  lw6gui_button_register_up (&(keyboard->arrow_right));
 	}
     }
   if (sym == const_data->keysym1_enter || sym == const_data->keysym2_enter)
@@ -270,6 +278,22 @@ key_up (lw6gui_keyboard_t * keyboard, SDL_Event * event,
 	  lw6gui_button_register_up (&(keyboard->key_esc));
 	}
     }
+  if (sym == const_data->keysym1_ctrl || sym == const_data->keysym2_ctrl)
+    {
+      if (!lw6gui_keyboard_is_pressed (keyboard, const_data->keysym1_ctrl)
+	  && !lw6gui_keyboard_is_pressed (keyboard, const_data->keysym2_ctrl))
+	{
+	  lw6gui_button_register_up (&(keyboard->key_ctrl));
+	}
+    }
+  if (sym == const_data->keysym1_alt || sym == const_data->keysym2_alt)
+    {
+      if (!lw6gui_keyboard_is_pressed (keyboard, const_data->keysym1_alt)
+	  && !lw6gui_keyboard_is_pressed (keyboard, const_data->keysym2_alt))
+	{
+	  lw6gui_button_register_up (&(keyboard->key_alt));
+	}
+    }
   if (sym == const_data->keysym1_pgup || sym == const_data->keysym2_pgup)
     {
       if (!lw6gui_keyboard_is_pressed (keyboard, const_data->keysym1_pgup)
@@ -304,10 +328,14 @@ mouse_button_down (lw6gui_mouse_t * mouse, SDL_Event * event,
     {
     case SDL_BUTTON_LEFT:
       lw6gui_button_register_down (&(mouse->button_left), timestamp);
+      lw6gui_mouse_drag_begin (mouse);
       break;
     case SDL_BUTTON_RIGHT:
       lw6gui_button_register_down (&(mouse->button_right), timestamp);
       break;
+    case SDL_BUTTON_MIDDLE:
+      lw6gui_button_register_down (&(mouse->button_middle), timestamp);
+      break;
     case SDL_BUTTON_WHEELUP:
       lw6gui_button_register_down (&(mouse->wheel_up), timestamp);
       /*
@@ -340,10 +368,14 @@ mouse_button_up (lw6gui_mouse_t * mouse, SDL_Event * event)
     {
     case SDL_BUTTON_LEFT:
       lw6gui_button_register_up (&(mouse->button_left));
+      lw6gui_mouse_drag_end (mouse);
       break;
     case SDL_BUTTON_RIGHT:
       lw6gui_button_register_up (&(mouse->button_right));
       break;
+    case SDL_BUTTON_MIDDLE:
+      lw6gui_button_register_up (&(mouse->button_middle));
+      break;
     case SDL_BUTTON_WHEELUP:
       lw6gui_button_register_up (&(mouse->wheel_up));
       break;
@@ -381,37 +413,53 @@ joystick_button_index (SDL_Event * event,
     case LW6GUI_JOYSTICK1_ID:
       if (event->jbutton.button == const_data->joystick1_button_a_index)
 	{
-	  ret = 0;
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_A;
 	}
       if (event->jbutton.button == const_data->joystick1_button_b_index)
 	{
-	  ret = 1;
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_B;
 	}
       if (event->jbutton.button == const_data->joystick1_button_c_index)
 	{
-	  ret = 2;
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_C;
 	}
       if (event->jbutton.button == const_data->joystick1_button_d_index)
 	{
-	  ret = 3;
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_D;
+	}
+      if (event->jbutton.button == const_data->joystick1_button_e_index)
+	{
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_E;
+	}
+      if (event->jbutton.button == const_data->joystick1_button_f_index)
+	{
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_F;
 	}
       break;
     case LW6GUI_JOYSTICK2_ID:
       if (event->jbutton.button == const_data->joystick2_button_a_index)
 	{
-	  ret = 0;
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_A;
 	}
       if (event->jbutton.button == const_data->joystick2_button_b_index)
 	{
-	  ret = 1;
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_B;
 	}
       if (event->jbutton.button == const_data->joystick2_button_c_index)
 	{
-	  ret = 2;
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_C;
 	}
       if (event->jbutton.button == const_data->joystick2_button_d_index)
 	{
-	  ret = 3;
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_D;
+	}
+      if (event->jbutton.button == const_data->joystick2_button_e_index)
+	{
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_E;
+	}
+      if (event->jbutton.button == const_data->joystick2_button_f_index)
+	{
+	  ret = LW6GUI_JOYSTICK_BUTTON_ID_F;
 	}
       break;
     }
@@ -456,18 +504,24 @@ joystick_button_down (lw6gui_joystick_t * joystick, int b, SDL_Event * event,
 {
   switch (b)
     {
-    case 0:
+    case LW6GUI_JOYSTICK_BUTTON_ID_A:
       lw6gui_button_register_down (&(joystick->button_a), timestamp);
       break;
-    case 1:
+    case LW6GUI_JOYSTICK_BUTTON_ID_B:
       lw6gui_button_register_down (&(joystick->button_b), timestamp);
       break;
-    case 2:
+    case LW6GUI_JOYSTICK_BUTTON_ID_C:
       lw6gui_button_register_down (&(joystick->button_c), timestamp);
       break;
-    case 3:
+    case LW6GUI_JOYSTICK_BUTTON_ID_D:
       lw6gui_button_register_down (&(joystick->button_d), timestamp);
       break;
+    case LW6GUI_JOYSTICK_BUTTON_ID_E:
+      lw6gui_button_register_down (&(joystick->button_e), timestamp);
+      break;
+    case LW6GUI_JOYSTICK_BUTTON_ID_F:
+      lw6gui_button_register_down (&(joystick->button_f), timestamp);
+      break;
     default:
       lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("joystick %d button %d ignored"),
 		  event->jbutton.which, event->jbutton.button);
@@ -480,18 +534,24 @@ joystick_button_up (lw6gui_joystick_t * joystick, int b, SDL_Event * event)
 {
   switch (b)
     {
-    case 0:
+    case LW6GUI_JOYSTICK_BUTTON_ID_A:
       lw6gui_button_register_up (&(joystick->button_a));
       break;
-    case 1:
+    case LW6GUI_JOYSTICK_BUTTON_ID_B:
       lw6gui_button_register_up (&(joystick->button_b));
       break;
-    case 2:
+    case LW6GUI_JOYSTICK_BUTTON_ID_C:
       lw6gui_button_register_up (&(joystick->button_c));
       break;
-    case 3:
+    case LW6GUI_JOYSTICK_BUTTON_ID_D:
       lw6gui_button_register_up (&(joystick->button_d));
       break;
+    case LW6GUI_JOYSTICK_BUTTON_ID_E:
+      lw6gui_button_register_up (&(joystick->button_e));
+      break;
+    case LW6GUI_JOYSTICK_BUTTON_ID_F:
+      lw6gui_button_register_up (&(joystick->button_f));
+      break;
     default:
       lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("joystick %d button %d ignored"),
 		  event->jbutton.which, event->jbutton.button);
