@@ -186,9 +186,18 @@ mod_gl_utils_menucache_item_t;
 
 typedef struct mod_gl_utils_menucache_array_s
 {
+  lw6map_color_set_t color_set;
   int last_stored_item;
     mod_gl_utils_menucache_item_t
     item_array[MOD_GL_UTILS_MENUCACHE_ARRAY_SIZE];
+  char *tooltip_str;
+  mod_gl_utils_bitmap_t *tooltip_bitmap;
+  char *help_str;
+  mod_gl_utils_bitmap_t *help_bitmap;
+  char *breadcrumbs_str;
+  mod_gl_utils_bitmap_t *breadcrumbs_bitmap;
+  char *popup_str;
+  mod_gl_utils_bitmap_t *popup_bitmap;
 }
 mod_gl_utils_menucache_array_t;
 
@@ -273,7 +282,6 @@ mod_gl_utils_const_data_t;
 
 typedef struct mod_gl_utils_texture_1x1_s
 {
-  lw6map_color_set_t color_set;
   mod_gl_utils_bitmap_t *color_base_fg;
   mod_gl_utils_bitmap_t *color_base_bg;
   mod_gl_utils_bitmap_t *color_alternate_fg;
@@ -377,6 +385,12 @@ typedef struct mod_gl_utils_counter_s
 }
 mod_gl_utils_counter_t;
 
+typedef struct mod_gl_utils_cache_s
+{
+  lw6map_color_set_t color_set;
+}
+mod_gl_utils_cache_t;
+
 typedef struct mod_gl_utils_context_s
 {
   lw6gui_resize_callback_func_t resize_callback;
@@ -403,9 +417,21 @@ typedef struct mod_gl_utils_context_s
   mod_gl_utils_icon_t icon;
   mod_gl_utils_counter_t counter;
   lw6sys_hash_t *bitmap_hash;
+  mod_gl_utils_cache_t cache;
 }
 mod_gl_utils_context_t;
 
+typedef struct mod_gl_utils_multiline_text_callback_data_s
+{
+  mod_gl_utils_context_t *utils_context;
+  TTF_Font *font;
+  SDL_Color sdl_color_bg;
+  SDL_Color sdl_color_fg;
+  lw6sys_whd_t shape;
+  lw6sys_xyz_t pos;
+  SDL_Surface *target;
+} mod_gl_utils_multiline_text_callback_data_t;
+
 /*
  * In bitmap.c
  */
@@ -527,6 +553,10 @@ extern int mod_gl_utils_bitmap_hash_refresh (mod_gl_utils_context_t *
 extern int mod_gl_utils_bitmap_hash_dump2disk (mod_gl_utils_context_t *
 					       utils_context, int force);
 
+/* gl-utils-cache.c */
+int mod_gl_utils_cache_update (mod_gl_utils_context_t * utils_context,
+			       lw6gui_look_t * look);
+
 /*
  * In capture.c
  */
@@ -656,6 +686,8 @@ extern void mod_gl_utils_display_texture_with_filter (mod_gl_utils_context_t *
  */
 extern void mod_gl_utils_draw_rectfill (SDL_Surface * surface, int x1, int y1,
 					int x2, int y2, Uint32 color);
+extern void mod_gl_utils_draw_set_alpha_for_color (SDL_Surface * surface,
+						   float alpha, Uint32 color);
 
 /*
  * In event.c
@@ -670,6 +702,14 @@ extern int mod_gl_utils_get_system_text_width (mod_gl_utils_context_t *
 					       utils_context, char *text);
 extern int mod_gl_utils_get_system_text_height (mod_gl_utils_context_t *
 						utils_context, char *text);
+extern mod_gl_utils_bitmap_t
+  * mod_gl_utils_multiline_text_write (mod_gl_utils_context_t *
+				       utils_context, TTF_Font * font,
+				       char *text,
+				       lw6map_color_couple_t * color,
+				       float alpha_bg, int max_width,
+				       int max_height, int border_size,
+				       int margin_size, int reformat_width);
 extern SDL_Surface *mod_gl_utils_blended_text_surface (mod_gl_utils_context_t
 						       * context,
 						       TTF_Font * font,
