@@ -288,6 +288,8 @@ _mod_gl_init (int argc, char *argv[], lw6gui_video_mode_t * video_mode,
 	      /*
 	       * Icon must be set before video mode is set
 	       */
+	      gl_context->utils_context.bitmap_hash =
+		mod_gl_utils_bitmap_hash_init ();
 	      mod_gl_utils_icon_set (&(gl_context->utils_context));
 	      SDL_EnableUNICODE (1);
 	    }
@@ -467,6 +469,12 @@ _mod_gl_quit (_mod_gl_context_t * gl_context)
       SDL_Quit ();
     }
 
+  if (gl_context->utils_context.bitmap_hash)
+    {
+      mod_gl_utils_bitmap_hash_quit (gl_context->utils_context.bitmap_hash);
+      gl_context->utils_context.bitmap_hash = NULL;
+    }
+
   /*
    * For some reason, I suspect some segfaults occur when
    * "dlclosing" mod-gl just after SDL_Quit. Might be a handler
