@@ -62,12 +62,13 @@
 #define LW6GUI_DISPLAY_HUD        0x00000040
 #define LW6GUI_DISPLAY_SCORE      0x00000080
 #define LW6GUI_DISPLAY_MENU       0x00000100
-#define LW6GUI_DISPLAY_PROGRESS   0x00000200
-#define LW6GUI_DISPLAY_LOG        0x00000400
-#define LW6GUI_DISPLAY_FPS        0x00000800
-#define LW6GUI_DISPLAY_MPS        0x00001000
-#define LW6GUI_DISPLAY_URL        0x00002000
-#define LW6GUI_DISPLAY_MOUSE      0x00004000
+#define LW6GUI_DISPLAY_META       0x00000200
+#define LW6GUI_DISPLAY_PROGRESS   0x00000400
+#define LW6GUI_DISPLAY_LOG        0x00000800
+#define LW6GUI_DISPLAY_FPS        0x00001000
+#define LW6GUI_DISPLAY_MPS        0x00002000
+#define LW6GUI_DISPLAY_URL        0x00004000
+#define LW6GUI_DISPLAY_MOUSE      0x00008000
 
 #define LW6GUI_DISPLAY_DEBUG_ZONES    0x00010000
 #define LW6GUI_DISPLAY_DEBUG_GRADIENT 0x00020000
@@ -228,6 +229,7 @@ typedef struct lw6gui_menuitem_s
 {
   u_int32_t id;
   char *label;
+  char *tooltip;
   int value;
   int enabled;
   int selected;
@@ -242,6 +244,8 @@ typedef struct lw6gui_menu_s
 {
   u_int32_t id;
   char *title;
+  char *help;
+  char *popup;
   int nb_items;
   lw6gui_menuitem_t *esc_item;
   lw6gui_menuitem_t **items;
@@ -250,6 +254,7 @@ typedef struct lw6gui_menu_s
   int nb_items_displayed;
   int order_of_selected_on_display;
   int allow_scroll;
+  lw6sys_list_t *breadcrumbs;
 }
 lw6gui_menu_t;
 
@@ -443,15 +448,17 @@ extern int lw6gui_look_zoom_in (lw6gui_look_t * look, float zoom_step);
 extern int lw6gui_look_zoom_out (lw6gui_look_t * look, float zoom_step);
 
 /* gui-menuitem.c */
-extern lw6gui_menuitem_t *lw6gui_menuitem_new (char *label, int value,
-					       int enabled, int selected,
-					       int colored);
+extern lw6gui_menuitem_t *lw6gui_menuitem_new (char *label, char *tooltip,
+					       int value, int enabled,
+					       int selected, int colored);
 extern void lw6gui_menuitem_free (lw6gui_menuitem_t * menuitem);
 
 extern int lw6gui_menuitem_memory_footprint (lw6gui_menuitem_t * menuitem);
 extern char *lw6gui_menuitem_repr (lw6gui_menuitem_t * menuitem);
 extern void lw6gui_menuitem_set_label (lw6gui_menuitem_t * menuitem,
 				       char *label, int64_t now);
+extern void lw6gui_menuitem_set_tooltip (lw6gui_menuitem_t * menuitem,
+					 char *label, int64_t now);
 extern void lw6gui_menuitem_set_value (lw6gui_menuitem_t * menuitem,
 				       int value, int64_t now);
 extern void lw6gui_menuitem_select (lw6gui_menuitem_t * menuitem, int state,
@@ -467,12 +474,16 @@ extern int lw6gui_menuitem_sync (lw6gui_menuitem_t * dst,
 				 lw6gui_menuitem_t * src);
 
 /* gui-menu.c */
-extern lw6gui_menu_t *lw6gui_menu_new (char *title, char *esc,
-				       int enable_esc);
+extern lw6gui_menu_t *lw6gui_menu_new (char *title, char *help, char *popup,
+				       char *esc, int enable_esc);
 extern void lw6gui_menu_free (lw6gui_menu_t * menu);
 extern int lw6gui_menu_memory_footprint (lw6gui_menu_t * menu);
 extern char *lw6gui_menu_repr (lw6gui_menu_t * menu);
 extern void lw6gui_menu_set_title (lw6gui_menu_t * menu, char *title);
+extern void lw6gui_menu_set_help (lw6gui_menu_t * menu, char *help);
+extern void lw6gui_menu_set_popup (lw6gui_menu_t * menu, char *popup);
+extern void lw6gui_menu_close_popup (lw6gui_menu_t * menu);
+extern int lw6gui_menu_has_popup (lw6gui_menu_t * menu);
 extern lw6gui_menuitem_t *lw6gui_menu_get_item (lw6gui_menu_t * menu,
 						int position);
 extern int lw6gui_menu_select (lw6gui_menu_t * menu, int position,
@@ -483,6 +494,8 @@ extern void lw6gui_menu_enable_esc (lw6gui_menu_t * menu, int state,
 				    int64_t now);
 extern int lw6gui_menu_scroll_up (lw6gui_menu_t * menu);
 extern int lw6gui_menu_scroll_down (lw6gui_menu_t * menu);
+extern int lw6gui_menu_set_breadcrumbs (lw6gui_menu_t * menu,
+					lw6sys_list_t * breadcrumbs);
 extern void lw6gui_menu_center (lw6gui_menu_t * menu, int position,
 				int max_displayed_items);
 extern int lw6gui_menu_insert (lw6gui_menu_t * menu,
@@ -495,18 +508,19 @@ extern int lw6gui_menu_remove (lw6gui_menu_t * menu, int position,
 extern void lw6gui_menu_update_display_range (lw6gui_menu_t * menu,
 					      int max_displayed_items);
 extern int lw6gui_menu_insert_for_id_use (lw6gui_menu_t * menu, char *label,
-					  int value, int enabled,
-					  int selected, int colored,
-					  int position, int64_t now);
-extern int lw6gui_menu_append_for_id_use (lw6gui_menu_t * menu, char *label,
-					  int value, int enabled,
-					  int selected, int colored,
+					  char *tooltip, int value,
+					  int enabled, int selected,
+					  int colored, int position,
 					  int64_t now);
+extern int lw6gui_menu_append_for_id_use (lw6gui_menu_t * menu, char *label,
+					  char *tooltip, int value,
+					  int enabled, int selected,
+					  int colored, int64_t now);
 extern int lw6gui_menu_remove_using_id (lw6gui_menu_t * menu, int menuitem_id,
 					int64_t now);
 extern void lw6gui_menu_sync_using_id (lw6gui_menu_t * menu, int menuitem_id,
-				       char *label, int value, int enabled,
-				       int selected, int colored,
+				       char *label, char *tooltip, int value,
+				       int enabled, int selected, int colored,
 				       int64_t now);
 extern int lw6gui_menu_is_same (lw6gui_menu_t * menu_a,
 				lw6gui_menu_t * menu_b);
