@@ -47,6 +47,13 @@ update_quick (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_quick
+ *
+ * Returns the list of keywords concerning quick options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_quick ()
 {
@@ -82,6 +89,8 @@ update_doc (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_LIST_HOOKS);
   lw6sys_list_push_back (list, LW6DEF_LIST_ADVANCED);
   lw6sys_list_push_back (list, LW6DEF_LIST_ALIASES);
+  lw6sys_list_push_back (list, LW6DEF_LIST_TEAM_COLORS);
+  lw6sys_list_push_back (list, LW6DEF_LIST_WEAPONS);
   lw6sys_list_push_back (list, LW6DEF_EXAMPLE_RULES_XML);
   lw6sys_list_push_back (list, LW6DEF_EXAMPLE_HINTS_XML);
   lw6sys_list_push_back (list, LW6DEF_EXAMPLE_STYLE_XML);
@@ -90,6 +99,13 @@ update_doc (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_doc
+ *
+ * Returns the list of keywords concerning self-documentation system.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_doc ()
 {
@@ -116,7 +132,8 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_MD5SUM);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_COPYRIGHT);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_LICENSE);
-  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_URL);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_HOME_URL);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_BUGS_URL);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_CONFIGURE_ARGS);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_GCC_VERSION);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_CFLAGS);
@@ -129,6 +146,8 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_POINTER_SIZE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_X86);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_HOST_OS);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_GNU);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_UNIX);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_MS_WINDOWS);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_MAC_OS_X);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_GP2X);
@@ -184,6 +203,13 @@ update_show (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_show
+ *
+ * Returns the list of keywords concerning the show options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_show ()
 {
@@ -216,6 +242,13 @@ update_path (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_path
+ *
+ * Returns the list of keywords concerning the path options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_path ()
 {
@@ -249,6 +282,13 @@ update_players (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_players
+ *
+ * Returns the list of keywords concerning the players options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_players ()
 {
@@ -291,6 +331,13 @@ update_input (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_input
+ *
+ * Returns the list of keywords concerning the input options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_input ()
 {
@@ -319,6 +366,13 @@ update_graphics (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_graphics
+ *
+ * Returns the list of keywords concerning the graphics options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_graphics ()
 {
@@ -347,6 +401,13 @@ update_sound (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_sound
+ *
+ * Returns the list of keywords concerning the sound options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_sound ()
 {
@@ -379,6 +440,13 @@ update_network (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_network
+ *
+ * Returns the list of keywords concerning the network options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_network ()
 {
@@ -409,6 +477,13 @@ update_map (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_map
+ *
+ * Returns the list of keywords concerning the map options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_map ()
 {
@@ -576,6 +651,13 @@ update_map_rules (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_rules
+ *
+ * Returns the list of keywords concerning the rules options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_map_rules ()
 {
@@ -618,6 +700,13 @@ update_map_hints (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_hints
+ *
+ * Returns the list of keywords concerning the hints options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_map_hints ()
 {
@@ -696,6 +785,13 @@ update_map_style (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_style
+ *
+ * Returns the list of keywords concerning the style options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_map_style ()
 {
@@ -742,6 +838,13 @@ update_map_teams (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_teams
+ *
+ * Returns the list of keywords concerning the teams options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_map_teams ()
 {
@@ -771,7 +874,8 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_MD5SUM);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_COPYRIGHT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_LICENSE);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_URL);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_HOME_URL);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_BUGS_URL);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_CONFIGURE_ARGS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_GCC_VERSION);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_CFLAGS);
@@ -784,6 +888,8 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_POINTER_SIZE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_IS_X86);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_HOST_OS);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_IS_GNU);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_IS_UNIX);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_IS_MS_WINDOWS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_IS_MAC_OS_X);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_IS_GP2X);
@@ -824,6 +930,8 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_LOG);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_LOG_GET_LEVEL);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_LOG_SET_LEVEL);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_MEGABYTES_AVAILABLE);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_OPENMP_GET_NUM_PROCS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_GET_DEFAULT_USER_DIR);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_GET_DEFAULT_CONFIG_FILE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_GET_DEFAULT_LOG_FILE);
@@ -849,6 +957,7 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_GET_MAP_PATH);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_GET_SCRIPT_FILE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_PATH_CONCAT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_PATH_FILE_ONLY);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_PATH_PARENT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_PATH_SPLIT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_SIGNAL_CUSTOM);
@@ -863,6 +972,8 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_IDLE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_SNOOZE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_URL_CANONIZE);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_ABOUT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_GET_DEFAULT_VALUE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_QUICK);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_DOC);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_SHOW);
@@ -881,8 +992,9 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_HOOKS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_ADVANCED);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_ALIASES);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_TEAM_COLORS);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_WEAPONS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_GET_DEFAULT_VALUE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6CFG_DEFAULTS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6CFG_LOAD);
   lw6sys_list_push_back (list, LW6DEF_C_LW6CFG_OPTION_EXISTS);
@@ -903,6 +1015,9 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MENU_ENABLE_ESC);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MENU_SCROLL_UP);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MENU_SCROLL_DOWN);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MENU_SET_BREADCRUMBS);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MENU_CLOSE_POPUP);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MENU_HAS_POPUP);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_DEFAULT_LOOK);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_LOOK_SET);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_LOOK_GET);
@@ -975,9 +1090,11 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_GET_MUSIC_DIR);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_TEAM_COLOR_INDEX_TO_KEY);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_TEAM_COLOR_KEY_TO_INDEX);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_TEAM_COLOR_INDEX_TO_LABEL);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_TEAM_COLOR_LIST);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_WEAPON_INDEX_TO_KEY);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_WEAPON_KEY_TO_INDEX);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_WEAPON_INDEX_TO_LABEL);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_WEAPON_LIST);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_RULES_GET_DEFAULT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_RULES_GET_MIN);
@@ -985,6 +1102,10 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_RULES_GET_INT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_STYLE_GET_DEFAULT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_TEAMS_GET_DEFAULT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_EXP_IS_TEAM_COLOR_ALLOWED);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_EXP_IS_WEAPON_ALLOWED);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_EXP_GET_UNLOCKED_TEAM_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_EXP_GET_UNLOCKED_WEAPON);
   lw6sys_list_push_back (list, LW6DEF_C_LW6KER_BUILD_GAME_STRUCT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6KER_BUILD_GAME_STATE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6KER_SYNC_GAME_STATE);
@@ -1023,13 +1144,16 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_CALIBRATE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_SPEED_UP);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_SLOW_DOWN);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_NEXT_ROUND);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_LAST_COMMIT_ROUND);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_REFERENCE_CURRENT_ROUND);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_REFERENCE_TARGET_ROUND);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_MAX_ROUND);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_NEXT_SEQ);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_LAST_COMMIT_SEQ);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_REFERENCE_CURRENT_SEQ);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_REFERENCE_TARGET_SEQ);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_MAX_SEQ);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_IS_OVER);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_DID_CURSOR_WIN);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_WINNER);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_LOOSER);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_SEQ_RANDOM_0);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SND_GET_BACKENDS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SND_NEW);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SND_POLL);
@@ -1061,6 +1185,7 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_POLL);
   lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_CLOSE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_GET_ID);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_GET_ENTRIES);
   lw6sys_list_push_back (list, LW6DEF_C_LW6BOT_GET_BACKENDS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6BOT_NEW);
   lw6sys_list_push_back (list, LW6DEF_C_LW6BOT_NEXT_MOVE);
@@ -1070,6 +1195,13 @@ update_funcs (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_funcs
+ *
+ * Returns the list of C-function exported to Guile.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_funcs ()
 {
@@ -1090,6 +1222,13 @@ update_hooks (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_hooks
+ *
+ * Returns the list of hooks.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_hooks ()
 {
@@ -1126,6 +1265,7 @@ update_advanced (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_HUD);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_SCORE);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_MENU);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_META);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_PROGRESS);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_LOG);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_FPS);
@@ -1161,10 +1301,20 @@ update_advanced (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_OPEN_RELAY);
   lw6sys_list_push_back (list, LW6DEF_NETWORK_RELIABILITY);
   lw6sys_list_push_back (list, LW6DEF_TROJAN);
+  lw6sys_list_push_back (list, LW6DEF_SIMULATE_BASIC);
+  lw6sys_list_push_back (list, LW6DEF_SIMULATE_FULL);
+  lw6sys_list_push_back (list, LW6DEF_TRAP_ERRORS);
 
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_advanced
+ *
+ * Returns the list of keywords concerning advanced options.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_advanced ()
 {
@@ -1195,6 +1345,13 @@ update_aliases (lw6sys_list_t ** list)
   return ((*list) != NULL);
 }
 
+/**
+ * lw6hlp_list_aliases
+ *
+ * Returns the list of command-line aliases.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
 lw6sys_list_t *
 lw6hlp_list_aliases ()
 {
@@ -1209,13 +1366,98 @@ lw6hlp_list_aliases ()
   return list;
 }
 
+static int
+update_team_colors (lw6sys_list_t ** list)
+{
+  lw6sys_list_push_back (list, LW6DEF_RED);
+  lw6sys_list_push_back (list, LW6DEF_GREEN);
+  lw6sys_list_push_back (list, LW6DEF_BLUE);
+  lw6sys_list_push_back (list, LW6DEF_YELLOW);
+  lw6sys_list_push_back (list, LW6DEF_CYAN);
+  lw6sys_list_push_back (list, LW6DEF_MAGENTA);
+  lw6sys_list_push_back (list, LW6DEF_ORANGE);
+  lw6sys_list_push_back (list, LW6DEF_LIGHTBLUE);
+  lw6sys_list_push_back (list, LW6DEF_PURPLE);
+  lw6sys_list_push_back (list, LW6DEF_PINK);
+
+  return ((*list) != NULL);
+}
+
+/**
+ * lw6hlp_list_team_colors
+ *
+ * Returns the list of team_colors.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
+lw6sys_list_t *
+lw6hlp_list_team_colors ()
+{
+  lw6sys_list_t *list = NULL;
+
+  list = lw6sys_list_new (NULL);
+  if (list)
+    {
+      update_team_colors (&list);
+    }
+
+  return list;
+}
+
+static int
+update_weapons (lw6sys_list_t ** list)
+{
+  lw6sys_list_push_back (list, LW6DEF_BERZERK);
+  lw6sys_list_push_back (list, LW6DEF_INVINCIBLE);
+  lw6sys_list_push_back (list, LW6DEF_ESCAPE);
+  lw6sys_list_push_back (list, LW6DEF_TURBO);
+  lw6sys_list_push_back (list, LW6DEF_TELEPORT);
+  lw6sys_list_push_back (list, LW6DEF_SCATTER);
+  lw6sys_list_push_back (list, LW6DEF_FIX);
+  lw6sys_list_push_back (list, LW6DEF_MIX);
+  lw6sys_list_push_back (list, LW6DEF_CONTROL);
+  lw6sys_list_push_back (list, LW6DEF_PERMUTATION);
+  lw6sys_list_push_back (list, LW6DEF_STEAL);
+  lw6sys_list_push_back (list, LW6DEF_ATOMIC);
+  lw6sys_list_push_back (list, LW6DEF_REVERSE);
+  lw6sys_list_push_back (list, LW6DEF_CRAZY);
+  lw6sys_list_push_back (list, LW6DEF_REWIND);
+  lw6sys_list_push_back (list, LW6DEF_ATTRACT);
+  lw6sys_list_push_back (list, LW6DEF_SHRINK);
+  lw6sys_list_push_back (list, LW6DEF_KAMIKAZE);
+  lw6sys_list_push_back (list, LW6DEF_DISAPPEAR);
+  lw6sys_list_push_back (list, LW6DEF_PLAGUE);
+
+  return ((*list) != NULL);
+}
+
+/**
+ * lw6hlp_list_weapons
+ *
+ * Returns the list of weapons.
+ *
+ * Return value: list of static strings (can't modify them)
+ */
+lw6sys_list_t *
+lw6hlp_list_weapons ()
+{
+  lw6sys_list_t *list = NULL;
+
+  list = lw6sys_list_new (NULL);
+  if (list)
+    {
+      update_weapons (&list);
+    }
+
+  return list;
+}
+
 /**
  * lw6hlp_list
  *
- * Returns a list of all available keywords.
+ * Returns the list of all available keywords.
  *
- * Return value: a list containing all the keywords. Strings are not
- *   dynamically allocated, you can't modify them.
+ * Return value: list of static strings (can't modify them)
  */
 lw6sys_list_t *
 lw6hlp_list ()
@@ -1234,7 +1476,8 @@ lw6hlp_list ()
 	&& update_map_hints (&list) && update_map_style (&list)
 	&& update_map_teams (&list) && update_funcs (&list)
 	&& update_hooks (&list) && update_advanced (&list)
-	&& update_aliases (&list);
+	&& update_aliases (&list) && update_team_colors (&list)
+	&& update_weapons (&list);
     }
 
   if (!ok)
