@@ -76,6 +76,8 @@ extern lw6sys_list_t *lw6hlp_list_funcs ();
 extern lw6sys_list_t *lw6hlp_list_hooks ();
 extern lw6sys_list_t *lw6hlp_list_advanced ();
 extern lw6sys_list_t *lw6hlp_list_aliases ();
+extern lw6sys_list_t *lw6hlp_list_team_colors ();
+extern lw6sys_list_t *lw6hlp_list_weapons ();
 extern lw6sys_list_t *lw6hlp_list ();
 
 /* hlp-print.c */
