@@ -729,35 +729,40 @@ _lw6ker_game_state_add_cursor (_lw6ker_game_state_t * game_state,
 		}
 	    }
 
-	  if (real_team_color >= 0)
+	  if (lw6map_team_color_is_valid (real_team_color))
 	    {
-	      if (real_team_color != team_color)
+	      if (lw6map_exp_is_team_color_allowed (rules, team_color))
 		{
-		  lw6sys_log (LW6SYS_LOG_DEBUG,
-			      _x_
-			      ("color shift: real_team_color=%d team_color=%d"),
-			      real_team_color, team_color);
-		}
-	      if (!_lw6ker_game_state_team_exists
-		  (game_state, real_team_color))
-		{
-		  _lw6ker_game_state_add_team (game_state, node_id,
-					       real_team_color);
-		}
-	      if (_lw6ker_game_state_team_exists
-		  (game_state, real_team_color))
-		{
-		  if (_lw6ker_cursor_get_start_xy
-		      (&x, &y, real_team_color, rules->start_position_mode,
-		       _lw6ker_game_state_get_rounds (game_state),
-		       &(game_state->map_state.shape), rules))
+		  if (real_team_color != team_color)
 		    {
-		      ret =
-			_lw6ker_cursor_array_enable (&
-						     (game_state->map_state.
-						      cursor_array), node_id,
-						     cursor_id,
-						     real_team_color, x, y);
+		      lw6sys_log (LW6SYS_LOG_DEBUG,
+				  _x_
+				  ("color shift: real_team_color=%d team_color=%d"),
+				  real_team_color, team_color);
+		    }
+		  if (!_lw6ker_game_state_team_exists
+		      (game_state, real_team_color))
+		    {
+		      _lw6ker_game_state_add_team (game_state, node_id,
+						   real_team_color);
+		    }
+		  if (_lw6ker_game_state_team_exists
+		      (game_state, real_team_color))
+		    {
+		      if (_lw6ker_cursor_get_start_xy
+			  (&x, &y, real_team_color,
+			   rules->start_position_mode,
+			   _lw6ker_game_state_get_rounds (game_state),
+			   &(game_state->map_state.shape), rules))
+			{
+			  ret =
+			    _lw6ker_cursor_array_enable (&
+							 (game_state->map_state.
+							  cursor_array),
+							 node_id, cursor_id,
+							 real_team_color, x,
+							 y);
+			}
 		    }
 		}
 	    }
@@ -1856,25 +1861,24 @@ int
 _lw6ker_game_state_get_winner (_lw6ker_game_state_t * game_state,
 			       int excluded_team)
 {
-  int nb_active_fighters_min;
+  int nb_active_fighters_max;
   int nb_active_fighters;
   int nb_teams;
   int i;
   int ret = LW6MAP_TEAM_COLOR_INVALID;
 
-  nb_active_fighters_min =
-    _lw6ker_game_state_get_nb_active_fighters (game_state);
+  nb_active_fighters_max = 0;
   nb_teams = _lw6ker_game_state_get_nb_teams (game_state);
   for (i = 0; i < nb_teams; ++i)
     {
       nb_active_fighters = 0;
       _lw6ker_game_state_get_team_info (game_state, i, NULL,
 					&nb_active_fighters);
-      if (nb_active_fighters < nb_active_fighters_min
+      if (nb_active_fighters > nb_active_fighters_max
 	  && nb_active_fighters > 0 && i != excluded_team)
 	{
 	  ret = i;
-	  nb_active_fighters_min = nb_active_fighters;
+	  nb_active_fighters_max = nb_active_fighters;
 	}
     }
 
@@ -1909,24 +1913,25 @@ int
 _lw6ker_game_state_get_looser (_lw6ker_game_state_t * game_state,
 			       int excluded_team)
 {
-  int nb_active_fighters_max;
+  int nb_active_fighters_min;
   int nb_active_fighters;
   int nb_teams;
   int i;
   int ret = LW6MAP_TEAM_COLOR_INVALID;
 
-  nb_active_fighters_max = 0;
+  nb_active_fighters_min =
+    _lw6ker_game_state_get_nb_active_fighters (game_state);
   nb_teams = _lw6ker_game_state_get_nb_teams (game_state);
   for (i = 0; i < nb_teams; ++i)
     {
       nb_active_fighters = 0;
       _lw6ker_game_state_get_team_info (game_state, i, NULL,
 					&nb_active_fighters);
-      if (nb_active_fighters > nb_active_fighters_max
+      if (nb_active_fighters < nb_active_fighters_min
 	  && nb_active_fighters > 0 && i != excluded_team)
 	{
 	  ret = i;
-	  nb_active_fighters_max = nb_active_fighters;
+	  nb_active_fighters_min = nb_active_fighters;
 	}
     }
 
