@@ -37,12 +37,18 @@ _lw6ker_team_init (_lw6ker_team_t * team, _lw6ker_map_struct_t * map_struct,
   int i;
 
   team->active = 0;
+  team->respawn_round = 0;
+  team->offline = 0;
   team->map_struct = map_struct;
   team->gradient =
     (_lw6ker_zone_state_t *) LW6SYS_CALLOC (map_struct->nb_zones *
 					    sizeof (_lw6ker_zone_state_t));
   team->cursor_ref_pot = rules->cursor_pot_init;
   team->last_spread_dir = LW6KER_DIR_NNE;
+  // team->charge is set to 0 because of CALLOC
+  team->weapon_id = LW6MAP_WEAPON_NONE;	// -1
+  // team->weapon_first_round set to 0 because of CALLOC
+  // team->weapon_last_round set to 0 because of CALLOC
 
   if (team->gradient)
     {
@@ -90,10 +96,17 @@ _lw6ker_team_sync (_lw6ker_team_t * dst, _lw6ker_team_t * src)
       && _lw6ker_map_struct_lazy_compare (dst->map_struct, src->map_struct))
     {
       dst->active = src->active;
+      dst->has_been_active = src->has_been_active;
+      dst->respawn_round = src->respawn_round;
+      dst->offline = src->offline;
       memcpy (dst->gradient, src->gradient,
 	      src->map_struct->nb_zones * sizeof (_lw6ker_zone_state_t));
       dst->cursor_ref_pot = src->cursor_ref_pot;
       dst->last_spread_dir = src->last_spread_dir;
+      dst->charge = src->charge;
+      dst->weapon_id = src->weapon_id;
+      dst->weapon_first_round = src->weapon_first_round;
+      dst->weapon_last_round = src->weapon_last_round;
       ret = 1;
     }
   else
@@ -112,6 +125,9 @@ _lw6ker_team_update_checksum (_lw6ker_team_t * team, u_int32_t * checksum)
   int i;
 
   lw6sys_checksum_update_int32 (checksum, team->active);
+  lw6sys_checksum_update_int32 (checksum, team->has_been_active);
+  lw6sys_checksum_update_int32 (checksum, team->respawn_round);
+  lw6sys_checksum_update_int32 (checksum, team->offline);
   // map_struct checksumed elsewhere
   for (i = 0; i < team->map_struct->nb_zones; ++i)
     {
@@ -119,18 +135,30 @@ _lw6ker_team_update_checksum (_lw6ker_team_t * team, u_int32_t * checksum)
     }
   lw6sys_checksum_update_int32 (checksum, team->cursor_ref_pot);
   lw6sys_checksum_update_int32 (checksum, team->last_spread_dir);
+  lw6sys_checksum_update_int32 (checksum, team->charge);
+  lw6sys_checksum_update_int32 (checksum, team->weapon_id);
+  lw6sys_checksum_update_int32 (checksum, team->weapon_first_round);
+  lw6sys_checksum_update_int32 (checksum, team->weapon_last_round);
 }
 
 void
 _lw6ker_team_activate (_lw6ker_team_t * team, lw6sys_xyz_t pos)
 {
   team->active = 1;
+  team->has_been_active = 1;
+  team->respawn_round = 0;
+  team->offline = 0;
+  team->charge = 0;
 }
 
 void
 _lw6ker_team_unactivate (_lw6ker_team_t * team)
 {
   team->active = 0;
+  // carefull, do not touch "has_been_active" !!!
+  team->respawn_round = 0;
+  team->offline = 0;
+  team->charge = 0;
 }
 
 void
@@ -180,3 +208,51 @@ _lw6ker_team_normalize_pot (_lw6ker_team_t * team, lw6map_rules_t * rules)
       team->cursor_ref_pot = rules->cursor_pot_init;
     }
 }
+
+int
+_lw6ker_team_get_charge_per1000 (_lw6ker_team_t * team)
+{
+  int ret = 0;
+
+  if (team->active)
+    {
+      ret = (team->charge * 1000) / _LW6KER_CHARGE_LIMIT;
+    }
+
+  return ret;
+}
+
+void
+_lw6ker_team_reset_charge (_lw6ker_team_t * team)
+{
+  team->charge = 0;
+}
+
+int
+_lw6ker_team_is_this_weapon_active (_lw6ker_team_t * team, int round,
+				    int weapon_id)
+{
+  return (team->weapon_id == weapon_id && team->weapon_first_round <= round
+	  && team->weapon_last_round >= round);
+}
+
+int
+_lw6ker_team_get_weapon_per1000_left (_lw6ker_team_t * team, int round)
+{
+  int ret = 0;
+  int rounds_done = 0;
+  int rounds_left = 0;
+  int duration = 0;
+
+  rounds_done = round - team->weapon_first_round;
+  rounds_left = team->weapon_last_round - round;
+  if (rounds_done >= 0 && rounds_left >= 0
+      && team->weapon_id >= LW6MAP_MIN_WEAPON_ID
+      && team->weapon_id <= LW6MAP_MAX_WEAPON_ID)
+    {
+      duration = lw6sys_max (1, rounds_done + rounds_left);
+      ret = lw6sys_max (1, lw6sys_min (1000, rounds_left * 1000 / duration));
+    }
+
+  return ret;
+}
