@@ -65,6 +65,7 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, char *png_file,
 		{
 		  png_uint_32 width;
 		  png_uint_32 height;
+		  png_uint_32 rowbytes;
 		  int max_width;
 		  int max_height;
 		  int bit_depth;
@@ -100,6 +101,8 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, char *png_file,
 		  png_get_IHDR (png_ptr, info_ptr, &width, &height,
 				&bit_depth, &color_type, NULL, NULL, NULL);
 
+		  rowbytes = png_get_rowbytes (png_ptr, info_ptr);
+
 		  if (color_type & PNG_COLOR_MASK_PALETTE)
 		    {
 		      lw6sys_log (LW6SYS_LOG_WARNING,
@@ -125,14 +128,13 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, char *png_file,
 		      format_ok = 0;
 		    }
 
-		  if (info_ptr->rowbytes != info_ptr->width * 4 ||
-		      bit_depth > 8)
+		  if (rowbytes != width * 4 || bit_depth > 8)
 		    {
 		      lw6sys_log (LW6SYS_LOG_WARNING,
 				  _x_
 				  ("can't load RGBA PNG file \"%s\", memory footprint is inconsistent, color_type=%d, rowbytes=%d, width=%d, step=%d, bit_depth=%d"),
 				  png_file, color_type,
-				  info_ptr->rowbytes, width, 4, bit_depth);
+				  rowbytes, width, 4, bit_depth);
 		      format_ok = 0;
 		    }
 
@@ -148,7 +150,7 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, char *png_file,
 			    {
 			      buf[row] =
 				(unsigned char *)
-				LW6SYS_MALLOC (info_ptr->rowbytes *
+				LW6SYS_MALLOC (rowbytes *
 					       sizeof (unsigned char));
 			      if (!buf[row])
 				{
@@ -247,7 +249,6 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file,
       cinfo.err = jpeg_std_error (&jerr);
       jpeg_stdio_src (&cinfo, f);
       jpeg_read_header (&cinfo, TRUE);
-      jpeg_start_decompress (&cinfo);
 
       memory_ok = 1;
       size_ok = 1;
@@ -268,6 +269,8 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file,
 
       if (size_ok)
 	{
+	  jpeg_start_decompress (&cinfo);
+
 	  buf =
 	    (unsigned char **) LW6SYS_MALLOC (cinfo.output_height *
 					      sizeof (unsigned char *));
@@ -364,9 +367,9 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file,
 			  _x_
 			  ("unable to allocate memory for RGBA JPEG file"));
 	    }
+	  jpeg_finish_decompress (&cinfo);
 	}
 
-      jpeg_finish_decompress (&cinfo);
       jpeg_destroy_decompress (&cinfo);
 
       fclose (f);
