@@ -34,7 +34,7 @@
 #define TEST_MAP_NOISE_PERCENT 30
 #define TEST_RULES_KEY LW6DEF_TOTAL_TIME
 #define TEST_RULES_VALUE 3600
-#define TEST_RULES_CHECKSUM 0x8409507b
+#define TEST_RULES_CHECKSUM 0x765d8d06
 #define TEST_STYLE_KEY LW6DEF_ZOOM
 #define TEST_STYLE_VALUE "1.0"
 #define TEST_TEAMS_KEY LW6DEF_BOT_IQ
@@ -105,6 +105,7 @@ test_color ()
     lw6map_color_couple_t color_couple;
     int i, j;
     char *key;
+    char *label;
 
     color_couple.bg = LW6SYS_COLOR_8_WHITE;
     color_couple.fg = LW6SYS_COLOR_8_BLACK;
@@ -123,11 +124,21 @@ test_color ()
 	key = lw6map_team_color_index_to_key (i);
 	if (key)
 	  {
-	    j = lw6map_team_color_key_to_index (key);
-	    if (i == j)
+	    label = lw6map_team_color_index_to_label (i);
+	    if (label)
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _x_ ("team_color key for %d is \"%s\""), i, key);
+		j = lw6map_team_color_key_to_index (key);
+		if (i == j)
+		  {
+		    lw6sys_log (LW6SYS_LOG_NOTICE,
+				_x_
+				("team_color key for %d is \"%s\" label is \"%s\""),
+				i, key, label);
+		  }
+		else
+		  {
+		    ret = 0;
+		  }
 	      }
 	    else
 	      {
@@ -418,13 +429,28 @@ test_exp ()
 
   {
     int i = 0;
+    lw6map_rules_t rules;
 
+    lw6map_rules_defaults (&rules);
     for (i = LW6MAP_RULES_MIN_EXP; i <= LW6MAP_RULES_MAX_EXP; ++i)
       {
 	lw6sys_log (LW6SYS_LOG_NOTICE,
-		    _x_ ("exp=%d highest_color=%d highest_weapon=%d"), i,
-		    lw6map_exp_get_highest_team_color_allowed (i),
-		    lw6map_exp_get_highest_weapon_allowed (i));
+		    _x_
+		    ("exp=%d highest_color=%d highest_weapon=%d unlocked_team_color=%d unlocked_weapon=%d"),
+		    i, lw6map_exp_get_highest_team_color_allowed (i),
+		    lw6map_exp_get_highest_weapon_allowed (i),
+		    lw6map_exp_get_unlocked_team_color (i),
+		    lw6map_exp_get_unlocked_weapon (i));
+      }
+    for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("team_color=%d allowed=%d"), i,
+		    lw6map_exp_is_team_color_allowed (&rules, i));
+      }
+    for (i = 0; i <= LW6MAP_MAX_WEAPON_ID; ++i)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("weapon=%d allowed=%d"), i,
+		    lw6map_exp_is_weapon_allowed (&rules, i));
       }
   }
   LW6SYS_TEST_FUNCTION_END;
@@ -735,17 +761,28 @@ test_weapon ()
   {
     int i, j;
     char *key;
+    char *label;
 
     for (i = 0; i <= LW6MAP_MAX_WEAPON_ID; ++i)
       {
 	key = lw6map_weapon_index_to_key (i);
 	if (key)
 	  {
-	    j = lw6map_weapon_key_to_index (key);
-	    if (i == j)
+	    label = lw6map_weapon_index_to_label (i);
+	    if (label)
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _x_ ("weapon key for %d is \"%s\""), i, key);
+		j = lw6map_weapon_key_to_index (key);
+		if (i == j)
+		  {
+		    lw6sys_log (LW6SYS_LOG_NOTICE,
+				_x_
+				("weapon key for %d is \"%s\" label is \"%s\""),
+				i, key, label);
+		  }
+		else
+		  {
+		    ret = 0;
+		  }
 	      }
 	    else
 	      {
