@@ -37,118 +37,25 @@
 typedef enum lw6map_weapon_e
 {
   LW6MAP_WEAPON_NONE = -1,
-/*
- * BERZERK: has super-strong attack for a limited time
- */
   LW6MAP_WEAPON_BERZERK = 0,
-/*
- * INVINCIBLE: no damage for a limited time
- */
   LW6MAP_WEAPON_INVINCIBLE = 1,
-/*
- * ESCAPE: fighters are put in the farest position,
- * that is as far as possible from the cursor. If one
- * is trapped, this will cause all fighters to magically
- * escape from any grip.
- */
   LW6MAP_WEAPON_ESCAPE = 2,
-/*
- * TURBO: goes faster for a limited time (stronger, faster)
- */
   LW6MAP_WEAPON_TURBO = 3,
-/*
- * TELEPORT: fighters are instantaneously placed as close
- * as possible to the cursor.
- */
   LW6MAP_WEAPON_TELEPORT = 4,
-/*
- * SCATTER: every fighters of every teams are just scattered
- * in random places all over the map. The proportion of fighters
- * in every team, their health and so on, is preserved, but
- * they are just put anywhere like stars in the sky.
- */
   LW6MAP_WEAPON_SCATTER = 5,
-/*
- * FIX: all the other teams are immobilized for some time,
- * only the team firing this weapon can move, but it can't
- * attack. Note that if you're trapped, this might not
- * be of great help.
- */
   LW6MAP_WEAPON_FIX = 6,
-/*
- * MIX: all the fighters of every teams are mixed, positions
- * are exchanged in a random manner, they globally stay at the
- * same place, but it's like they were stirred in a bowl.
- */
   LW6MAP_WEAPON_MIX = 7,
-/*
- * CONTROL: your cursor stays in place, and you take control
- * of all other cursors for a limited time, just drag the other
- * teams where you want.
- */
   LW6MAP_WEAPON_CONTROL = 8,
-/*
- * PERMUTATION: teams are exchanged, for instance red becomes
- * green, green becomes blue and blue becomes red. Works only
- * if there are at least 3 teams on the battlefield. How the
- * swap/exchange is done depends on moon phases, this is a
- * double-edged weapon.
- */
   LW6MAP_WEAPON_PERMUTATION = 9,
-/*
- * STEAL: steal some other fighters from other teams.
- */
   LW6MAP_WEAPON_STEAL = 10,
-/*
- * ATOMIC: nuclear explosion, all fighters in a circle
- * near the caller's cursor are set to minimal health,
- * ready to die.
- */
   LW6MAP_WEAPON_ATOMIC = 11,
-/*
- * REVERSE: moves continue to operate the right way but
- * attacks are done in reverse mode, that is if you were trapped
- * then you get maximal attack, fighting against those
- * pursuing you. Limited time of course.
- */
   LW6MAP_WEAPON_REVERSE = 12,
-/*
- * CRAZY: for some time, all other teams just go crazy and
- * move/attack in random directions.
- */
   LW6MAP_WEAPON_CRAZY = 13,
-/*
- * REWIND: make the battlefield be like it was X seconds ago.
- * X (the time shift) depends on settings and what is available
- * in memory.
- */
   LW6MAP_WEAPON_REWIND = 14,
-/*
- * ATTRACT: all the fighters from every team are packed near
- * the caller's cursor.
- */
   LW6MAP_WEAPON_ATTRACT = 15,
-/*
- * SHRINK: diminishes the amount of fighters on the map, in a
- * proportionnal manner.
- */
   LW6MAP_WEAPON_SHRINK = 16,
-/*
- * KAMIKAZE: requires at least 3 teams to be on the battlefield,
- * you die and with you dies the one who was the strongest
- * at this moment.
- */
   LW6MAP_WEAPON_KAMIKAZE = 17,
-/*
- * DISAPPEAR: you disappear for some time, not on the battlefield
- * anymore, just to reappear later, with the same number of
- * fighters, in the same state, but somewhere else.
- */
   LW6MAP_WEAPON_DISAPPEAR = 18,
-/*
- * PLAGUE: general disease for everyone including you, everyone
- * constantly looses health for some time.
- */
   LW6MAP_WEAPON_PLAGUE = 19
 }
 lw6map_weapon_t;
@@ -171,20 +78,20 @@ lw6map_weapon_t;
 #define LW6MAP_RULES_FRAGS_MODE_PROPORTIONAL 3
 
 #define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_AGGRESSIVE 100
-#define LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE 10
-#define LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE 1000
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE 5
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE 2000
 
 #define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_VULNERABLE 100
-#define LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE 10
-#define LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE 1000
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE 5
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE 2000
 
 #define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_MOBILE 0
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_MOBILE -3
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_MOBILE 3
 
 #define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_FAST 100
-#define LW6MAP_RULES_MIN_TEAM_PROFILE_FAST 10
-#define LW6MAP_RULES_MAX_TEAM_PROFILE_FAST 1000
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_FAST 5
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_FAST 2000
 
 #define LW6MAP_RULES_TEAM_PROFILE_WEAPON_MODE_NONE 0
 #define LW6MAP_RULES_TEAM_PROFILE_WEAPON_MODE_BY_ID 1
@@ -470,83 +377,83 @@ lw6map_weapon_t;
 #define LW6MAP_RULES_MIN_USE_TEAM_PROFILES 0
 #define LW6MAP_RULES_MAX_USE_TEAM_PROFILES 1
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_RED_AGGRESSIVE 90
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_RED_AGGRESSIVE 220
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_RED_AGGRESSIVE LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_RED_AGGRESSIVE LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_GREEN_AGGRESSIVE 100
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_GREEN_AGGRESSIVE 70
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_GREEN_AGGRESSIVE LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_GREEN_AGGRESSIVE LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_BLUE_AGGRESSIVE 300
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_BLUE_AGGRESSIVE 150
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_BLUE_AGGRESSIVE LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_BLUE_AGGRESSIVE LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_YELLOW_AGGRESSIVE 300
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_YELLOW_AGGRESSIVE 200
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_YELLOW_AGGRESSIVE LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_YELLOW_AGGRESSIVE LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_CYAN_AGGRESSIVE 110
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_CYAN_AGGRESSIVE 44
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_CYAN_AGGRESSIVE LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_CYAN_AGGRESSIVE LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_MAGENTA_AGGRESSIVE 60
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_MAGENTA_AGGRESSIVE 192
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_MAGENTA_AGGRESSIVE LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_MAGENTA_AGGRESSIVE LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_ORANGE_AGGRESSIVE 30
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_ORANGE_AGGRESSIVE 48
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_ORANGE_AGGRESSIVE LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_ORANGE_AGGRESSIVE LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_LIGHTBLUE_AGGRESSIVE 1000
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_LIGHTBLUE_AGGRESSIVE 200
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_LIGHTBLUE_AGGRESSIVE LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_LIGHTBLUE_AGGRESSIVE LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PURPLE_AGGRESSIVE 40
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PURPLE_AGGRESSIVE 32
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_PURPLE_AGGRESSIVE LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_PURPLE_AGGRESSIVE LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PINK_AGGRESSIVE 800
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PINK_AGGRESSIVE 640
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_PINK_AGGRESSIVE LW6MAP_RULES_MIN_TEAM_PROFILE_AGGRESSIVE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_PINK_AGGRESSIVE LW6MAP_RULES_MAX_TEAM_PROFILE_AGGRESSIVE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_RED_VULNERABLE 120
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_RED_VULNERABLE 110
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_RED_VULNERABLE LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_RED_VULNERABLE LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_GREEN_VULNERABLE 45
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_GREEN_VULNERABLE 30
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_GREEN_VULNERABLE LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_GREEN_VULNERABLE LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_BLUE_VULNERABLE 90
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_BLUE_VULNERABLE 60
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_BLUE_VULNERABLE LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_BLUE_VULNERABLE LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_YELLOW_VULNERABLE 120
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_YELLOW_VULNERABLE 90
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_YELLOW_VULNERABLE LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_YELLOW_VULNERABLE LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_CYAN_VULNERABLE 10
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_CYAN_VULNERABLE 12
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_CYAN_VULNERABLE LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_CYAN_VULNERABLE LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_MAGENTA_VULNERABLE 600
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_MAGENTA_VULNERABLE 1920
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_MAGENTA_VULNERABLE LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_MAGENTA_VULNERABLE LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_ORANGE_VULNERABLE 90
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_ORANGE_VULNERABLE 144
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_ORANGE_VULNERABLE LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_ORANGE_VULNERABLE LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_LIGHTBLUE_VULNERABLE 40
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_LIGHTBLUE_VULNERABLE 8
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_LIGHTBLUE_VULNERABLE LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_LIGHTBLUE_VULNERABLE LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PURPLE_VULNERABLE 20
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PURPLE_VULNERABLE 16
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_PURPLE_VULNERABLE LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_PURPLE_VULNERABLE LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE
 
-#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PINK_VULNERABLE 800
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PINK_VULNERABLE 640
 #define LW6MAP_RULES_MIN_TEAM_PROFILE_PINK_VULNERABLE LW6MAP_RULES_MIN_TEAM_PROFILE_VULNERABLE
 #define LW6MAP_RULES_MAX_TEAM_PROFILE_PINK_VULNERABLE LW6MAP_RULES_MAX_TEAM_PROFILE_VULNERABLE
 
@@ -942,17 +849,6 @@ extern char *LW6MAP_RULES_LIST[];
  */
 #define LW6MAP_STYLE_DEFAULT_MUSIC_EXCLUDE "Chadburn"
 
-#define LW6MAP_TEAM_COLOR_KEY_RED "red"
-#define LW6MAP_TEAM_COLOR_KEY_GREEN "green"
-#define LW6MAP_TEAM_COLOR_KEY_BLUE "blue"
-#define LW6MAP_TEAM_COLOR_KEY_YELLOW "yellow"
-#define LW6MAP_TEAM_COLOR_KEY_CYAN "cyan"
-#define LW6MAP_TEAM_COLOR_KEY_MAGENTA "magenta"
-#define LW6MAP_TEAM_COLOR_KEY_ORANGE "orange"
-#define LW6MAP_TEAM_COLOR_KEY_LIGHTBLUE "lightblue"
-#define LW6MAP_TEAM_COLOR_KEY_PURPLE "purple"
-#define LW6MAP_TEAM_COLOR_KEY_PINK "pink"
-
 #define LW6MAP_NB_TEAM_COLORS LW6MAP_MAX_NB_TEAMS
 
 #define LW6MAP_BUILTIN_DEFAULT_WIDTH 256
@@ -973,33 +869,12 @@ typedef enum lw6map_team_color_e
     8, LW6MAP_TEAM_COLOR_PINK = 9
 } lw6map_team_color_t;
 
-#define LW6MAP_WEAPON_KEY_BERZERK "berzerk"
-#define LW6MAP_WEAPON_KEY_INVINCIBLE "invincible"
-#define LW6MAP_WEAPON_KEY_ESCAPE "escape"
-#define LW6MAP_WEAPON_KEY_TURBO "turbo"
-#define LW6MAP_WEAPON_KEY_TELEPORT "teleport"
-#define LW6MAP_WEAPON_KEY_SCATTER "scatter"
-#define LW6MAP_WEAPON_KEY_FIX "fix"
-#define LW6MAP_WEAPON_KEY_MIX "mix"
-#define LW6MAP_WEAPON_KEY_CONTROL "control"
-#define LW6MAP_WEAPON_KEY_PERMUTATION "permutation"
-#define LW6MAP_WEAPON_KEY_STEAL "steal"
-#define LW6MAP_WEAPON_KEY_ATOMIC "atomic"
-#define LW6MAP_WEAPON_KEY_REVERSE "reverse"
-#define LW6MAP_WEAPON_KEY_CRAZY "crazy"
-#define LW6MAP_WEAPON_KEY_REWIND "rewind"
-#define LW6MAP_WEAPON_KEY_ATTRACT "attract"
-#define LW6MAP_WEAPON_KEY_SHRINK "shrink"
-#define LW6MAP_WEAPON_KEY_KAMIKAZE "kamikaze"
-#define LW6MAP_WEAPON_KEY_DISAPPEAR "disappear"
-#define LW6MAP_WEAPON_KEY_PLAGUE "plague"
-
 #define LW6MAP_TEAMS_NB_PLAYERS 4
 
-#define LW6MAP_TEAMS_DEFAULT_PLAYER1_COLOR LW6MAP_TEAM_COLOR_KEY_RED
-#define LW6MAP_TEAMS_DEFAULT_PLAYER2_COLOR LW6MAP_TEAM_COLOR_KEY_GREEN
-#define LW6MAP_TEAMS_DEFAULT_PLAYER3_COLOR LW6MAP_TEAM_COLOR_KEY_BLUE
-#define LW6MAP_TEAMS_DEFAULT_PLAYER4_COLOR LW6MAP_TEAM_COLOR_KEY_YELLOW
+#define LW6MAP_TEAMS_DEFAULT_PLAYER1_COLOR LW6DEF_RED
+#define LW6MAP_TEAMS_DEFAULT_PLAYER2_COLOR LW6DEF_GREEN
+#define LW6MAP_TEAMS_DEFAULT_PLAYER3_COLOR LW6DEF_BLUE
+#define LW6MAP_TEAMS_DEFAULT_PLAYER4_COLOR LW6DEF_YELLOW
 
 #define LW6MAP_TEAMS_PLAYER1_INDEX 0
 #define LW6MAP_TEAMS_PLAYER2_INDEX 1
@@ -1016,15 +891,15 @@ typedef enum lw6map_team_color_e
 #define LW6MAP_TEAMS_MIN_BOT_IQ 0
 #define LW6MAP_TEAMS_MAX_BOT_IQ 200
 
-#define LW6MAP_TEAMS_DEFAULT_BOT1_COLOR LW6MAP_TEAM_COLOR_KEY_GREEN
-#define LW6MAP_TEAMS_DEFAULT_BOT2_COLOR LW6MAP_TEAM_COLOR_KEY_BLUE
-#define LW6MAP_TEAMS_DEFAULT_BOT3_COLOR LW6MAP_TEAM_COLOR_KEY_YELLOW
-#define LW6MAP_TEAMS_DEFAULT_BOT4_COLOR LW6MAP_TEAM_COLOR_KEY_CYAN
-#define LW6MAP_TEAMS_DEFAULT_BOT5_COLOR LW6MAP_TEAM_COLOR_KEY_MAGENTA
-#define LW6MAP_TEAMS_DEFAULT_BOT6_COLOR LW6MAP_TEAM_COLOR_KEY_ORANGE
-#define LW6MAP_TEAMS_DEFAULT_BOT7_COLOR LW6MAP_TEAM_COLOR_KEY_LIGHTBLUE
-#define LW6MAP_TEAMS_DEFAULT_BOT8_COLOR LW6MAP_TEAM_COLOR_KEY_PURPLE
-#define LW6MAP_TEAMS_DEFAULT_BOT9_COLOR LW6MAP_TEAM_COLOR_KEY_PINK
+#define LW6MAP_TEAMS_DEFAULT_BOT1_COLOR LW6DEF_GREEN
+#define LW6MAP_TEAMS_DEFAULT_BOT2_COLOR LW6DEF_BLUE
+#define LW6MAP_TEAMS_DEFAULT_BOT3_COLOR LW6DEF_YELLOW
+#define LW6MAP_TEAMS_DEFAULT_BOT4_COLOR LW6DEF_CYAN
+#define LW6MAP_TEAMS_DEFAULT_BOT5_COLOR LW6DEF_MAGENTA
+#define LW6MAP_TEAMS_DEFAULT_BOT6_COLOR LW6DEF_ORANGE
+#define LW6MAP_TEAMS_DEFAULT_BOT7_COLOR LW6DEF_LIGHTBLUE
+#define LW6MAP_TEAMS_DEFAULT_BOT8_COLOR LW6DEF_PURPLE
+#define LW6MAP_TEAMS_DEFAULT_BOT9_COLOR LW6DEF_PINK
 
 #define LW6MAP_TEAMS_DEFAULT_BOT1_AI "idiot"
 #define LW6MAP_TEAMS_DEFAULT_BOT2_AI "idiot"
@@ -1066,7 +941,9 @@ lw6map_teams_t;
 typedef struct lw6map_metadata_s
 {
   char *title;
-  char *readme;
+  char *author;
+  char *description;
+  char *license;
   int vanilla_exp;
 } lw6map_metadata_t;
 
@@ -1264,6 +1141,7 @@ extern int lw6map_color_is_same (lw6map_color_couple_t * color1,
 				 lw6map_color_couple_t * color2);
 extern char *lw6map_team_color_index_to_key (int index);
 extern int lw6map_team_color_key_to_index (char *key);
+extern char *lw6map_team_color_index_to_label (int index);
 static inline int
 lw6map_team_color_is_valid (int team_color)
 {
@@ -1295,6 +1173,12 @@ extern lw6map_level_t *lw6map_dup (lw6map_level_t * source,
 /* map-exp.c */
 extern int lw6map_exp_get_highest_team_color_allowed (int exp);
 extern int lw6map_exp_get_highest_weapon_allowed (int exp);
+extern int lw6map_exp_is_team_color_allowed (lw6map_rules_t * rules,
+					     int team_color_id);
+extern int lw6map_exp_is_weapon_allowed (lw6map_rules_t * rules,
+					 int weapon_id);
+extern int lw6map_exp_get_unlocked_team_color (int exp);
+extern int lw6map_exp_get_unlocked_weapon (int exp);
 
 /* map-hexa.c */
 extern char *lw6map_to_hexa (lw6map_level_t * level);
@@ -1321,9 +1205,7 @@ extern int lw6map_local_info_set_music_dir (lw6map_local_info_t *
 					    local_info, char *music_dir);
 extern void lw6map_local_info_clear (lw6map_local_info_t * local_info);
 
-/*
- * In metadata.c
- */
+/* map-metadata.c */
 extern void lw6map_metadata_defaults (lw6map_metadata_t * metadata);
 extern void lw6map_metadata_clear (lw6map_metadata_t * metadata);
 extern int lw6map_metadata_is_same (lw6map_metadata_t * metadata_a,
@@ -1339,9 +1221,7 @@ extern int lw6map_meta_layer_builtin_custom (lw6map_meta_layer_t * meta_layer,
 					     int w, int h, int analog,
 					     int noise_percent, int seed);
 
-/*
- * In rules.c
- */
+/* map-rules.c */
 extern void lw6map_rules_defaults (lw6map_rules_t * rules);
 extern void lw6map_rules_copy (lw6map_rules_t * dst, lw6map_rules_t * src);
 extern void lw6map_rules_update_checksum (lw6map_rules_t * rules,
@@ -1368,9 +1248,7 @@ extern char *lw6map_param_get (lw6map_param_t * param, char *key);
 extern int lw6map_param_is_same (lw6map_param_t * param_a,
 				 lw6map_param_t * param_b);
 
-/*
- * In style.c
- */
+/* map-style.c */
 extern void lw6map_style_zero (lw6map_style_t * style);
 extern void lw6map_style_defaults (lw6map_style_t * style);
 extern void lw6map_style_clear (lw6map_style_t * style);
@@ -1397,9 +1275,10 @@ extern int lw6map_teams_is_same (lw6map_teams_t * teams_a,
 /* map-test.c */
 extern int lw6map_test (int mode);
 
-/*
- * In texture.c
- */
+/* map-texture.c */
+extern int lw6map_texture_from_body (lw6map_texture_t * texture,
+				     lw6map_body_t * body,
+				     lw6map_color_couple_t * color);
 extern void lw6map_texture_clear (lw6map_texture_t * texture);
 extern int lw6map_texture_coord_from_body (lw6map_level_t * level,
 					   int *texture_x, int *texture_y,
@@ -1408,18 +1287,16 @@ extern lw6sys_color_8_t lw6map_texture_get_with_body_coord (lw6map_level_t *
 							    level,
 							    int body_x,
 							    int body_y);
-extern int lw6map_texture_from_body (lw6map_texture_t * texture,
-				     lw6map_body_t * body,
-				     lw6map_color_couple_t * color);
 extern int lw6map_texture_has_alpha (lw6map_texture_t * texture);
 
 /* map-weapon.c */
 extern char *lw6map_weapon_index_to_key (int index);
 extern int lw6map_weapon_key_to_index (char *key);
+extern char *lw6map_weapon_index_to_label (int index);
 static inline int
 lw6map_weapon_is_valid (int weapon)
 {
   return (weapon >= 0 && weapon <= LW6MAP_MAX_WEAPON_ID);
 }
 
-#endif /*  */
+#endif
