@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -42,12 +42,10 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 			   &const_data->listen_backlog);
       lw6cfg_read_xml_int (key, value, "chunk-size", &const_data->chunk_size);
       lw6cfg_read_xml_int (key, value, "line-size", &const_data->line_size);
-    }
-
-  if (!strcmp (element, "float"))
-    {
-      lw6cfg_read_xml_float (key, value, "line-delay",
-			     &const_data->line_delay);
+      lw6cfg_read_xml_int (key, value, "line-delay-msec",
+			   &const_data->line_delay_msec);
+      lw6cfg_read_xml_int (key, value, "dns-cache-hash-size",
+			   &const_data->dns_cache_hash_size);
     }
 }
 
@@ -55,7 +53,7 @@ read_callback (void *callback_data, char *element, char *key, char *value)
  * Loads constants.
  */
 int
-_lw6net_const_init (int argc, char *argv[])
+_lw6net_const_init (int argc, char *argv[], _lw6net_const_data_t * const_data)
 {
   int ret = 0;
   char *const_file = NULL;
@@ -69,14 +67,11 @@ _lw6net_const_init (int argc, char *argv[])
 
       if (const_file)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("reading \"%s\""), const_file);
+	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("reading \"%s\""), const_file);
 
 	  ret =
 	    lw6cfg_read_key_value_xml_file (const_file, read_callback,
-					    (void *)
-					    &
-					    (_lw6net_global_context->
-					     const_data));
+					    (void *) const_data);
 	  LW6SYS_FREE (const_file);
 	}
       LW6SYS_FREE (data_root_dir);
@@ -87,12 +82,10 @@ _lw6net_const_init (int argc, char *argv[])
    * Anyway with MTUs being arround 1500, the limit is purely theorical,
    * kernel network stack will stop us before that.
    */
-  _lw6net_global_context->const_data.chunk_size =
-    lw6sys_min (LW6NET_MAX_PACKET_SIZE,
-		_lw6net_global_context->const_data.chunk_size);
-  _lw6net_global_context->const_data.line_size =
-    lw6sys_min (LW6NET_MAX_PACKET_SIZE,
-		_lw6net_global_context->const_data.line_size);
+  const_data->chunk_size =
+    lw6sys_min (LW6NET_MAX_CHUNK_SIZE, const_data->chunk_size);
+  const_data->line_size =
+    lw6sys_min (LW6NET_MAX_LINE_SIZE, const_data->line_size);
 
   return ret;
 }
@@ -101,8 +94,7 @@ _lw6net_const_init (int argc, char *argv[])
  * Unload constants, free memory
  */
 void
-_lw6net_const_quit ()
+_lw6net_const_quit (_lw6net_const_data_t * const_data)
 {
-  memset (&(_lw6net_global_context->const_data), 0,
-	  sizeof (_lw6net_const_data_t));
+  memset (const_data, 0, sizeof (_lw6net_const_data_t));
 }
