@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,14 +28,14 @@
 #include "mod-csound-internal.h"
 
 _mod_csound_context_t *
-_mod_csound_init (int argc, char *argv[], float sound_volume,
+_mod_csound_init (int argc, char *argv[], float fx_volume, float water_volume,
 		  float music_volume)
 {
   _mod_csound_context_t *csound_context = NULL;
   int ok = 0;
 
   lw6sys_log (LW6SYS_LOG_INFO,
-	      _("csound init volume=%01.2f/%01.2f"), sound_volume,
+	      _x_ ("csound init volume=%01.2f/%01.2f"), fx_volume,
 	      music_volume);
 
   csound_context =
@@ -44,7 +44,8 @@ _mod_csound_init (int argc, char *argv[], float sound_volume,
     {
       if (_mod_csound_path_init (csound_context, argc, argv))
 	{
-	  _mod_csound_set_sound_volume (csound_context, sound_volume);
+	  _mod_csound_set_fx_volume (csound_context, fx_volume);
+	  _mod_csound_set_water_volume (csound_context, water_volume);
 	  _mod_csound_set_music_volume (csound_context, music_volume);
 
 	  ok = 1;
@@ -53,17 +54,23 @@ _mod_csound_init (int argc, char *argv[], float sound_volume,
 
   if (!ok)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to init csound module"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to init csound module"));
       _mod_csound_quit (csound_context);
     }
 
   return csound_context;
 }
 
+void
+_mod_csound_poll (_mod_csound_context_t * csound_context)
+{
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("csound poll"));
+}
+
 void
 _mod_csound_quit (_mod_csound_context_t * csound_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO, _("csound quit"));
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("csound quit"));
   _mod_csound_path_quit (csound_context);
   LW6SYS_FREE (csound_context);
 }
