@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,26 +28,14 @@
 #include "mod-httpd-internal.h"
 
 char *
-_mod_httpd_repr (_httpd_context_t * httpd_context,
-		 lw6srv_connection_t * connection)
+_mod_httpd_repr (_mod_httpd_context_t * httpd_context,
+		 lw6cnx_connection_t * connection)
 {
   char *ret = NULL;
 
   ret =
-    lw6sys_new_sprintf (_("httpd connexion with %s:%d"),
-			connection->client_id.client_ip,
-			connection->client_id.client_port);
-
-  return ret;
-}
-
-char *
-_mod_httpd_error (_httpd_context_t * httpd_context,
-		  lw6srv_connection_t * connection)
-{
-  char *ret = NULL;
-
-  // todo
+    lw6sys_new_sprintf (_x_ ("httpd connexion with %s:%d"),
+			connection->remote_ip, connection->remote_port);
 
   return ret;
 }
