@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,4 +28,4 @@
 #include "sys-internal.h"
 
 _lw6sys_global_t _lw6sys_global =
-  { _LW6SYS_DEBUG_DEFAULT, LW6SYS_LOG_DEFAULT_ID };
+  { _LW6SYS_DEBUG_DEFAULT, LW6SYS_LOG_DEFAULT_ID, _LW6SYS_QUIT_DEFAULT };
