@@ -33,6 +33,7 @@
 #include <time.h>
 #include <sys/time.h>
 #include <errno.h>
+#include <math.h>
 
 #ifdef LW6_GTK
 #include <gtk/gtk.h>
@@ -41,6 +42,7 @@
 #define HISTORY_LENGTH 256
 #define LEVEL_LENGTH 80
 #define MSGBOX_LENGTH 4096
+#define BT_FACTOR 2
 /*
  * For some reason seams on GNU/Linux (gtk2/xorg) systems
  * the message box is trimmed at 64 chars width. 128 makes
@@ -614,15 +616,16 @@ log_to_history (char *level_str, char *fmt, va_list ap)
  * This function not declared static so that we're sure it's never inlined
  * because that could wreck the backtrace construction. It's not exported
  * in the sys/sys.h header anyway, we don't want others to use it, it still
- * does have the lw6sys_ prefix to avoid name conflicts.
+ * does have the _lw6sys_ prefix to avoid name conflicts.
  */
 void
-lw6sys_msgbox_alert (char *level_str, char *file, int line, char *fmt,
-		     va_list ap)
+_lw6sys_msgbox_alert (char *level_str, char *file, int line, char *fmt,
+		      va_list ap)
 {
   char message_raw[MSGBOX_LENGTH + 1];
   char message_full[MSGBOX_LENGTH + 1];
   char *bt = NULL;
+  int bt_width = 0;
   int free_bt = 0;
 
   _lw6sys_buf_vsnprintf (message_raw, MSGBOX_LENGTH, fmt, ap);
@@ -630,7 +633,8 @@ lw6sys_msgbox_alert (char *level_str, char *file, int line, char *fmt,
   bt = lw6sys_backtrace (2);	// skip this function & caller  
   if (bt)
     {
-      lw6sys_str_reformat_this (bt, MSGBOX_WIDTH);
+      bt_width = lw6sys_max (MSGBOX_WIDTH, sqrt (strlen (bt)) * BT_FACTOR);
+      lw6sys_str_reformat_this (bt, bt_width);
       free_bt = 1;
     }
   else
@@ -638,8 +642,9 @@ lw6sys_msgbox_alert (char *level_str, char *file, int line, char *fmt,
       bt = "";
     }
   lw6sys_buf_sprintf (message_full, MSGBOX_LENGTH,
-		      "%s (%s:%d)\n\n%s\n\nbacktrace: %s", level_str, file,
-		      line, message_raw, bt);
+		      "%s (%s:%d)\n\n%s\n\n%s: %s\n\n%s: %s", level_str, file,
+		      line, message_raw, _("Backtrace"), bt, _("Report bugs"),
+		      lw6sys_build_get_bugs_url ());
   if (free_bt)
     {
       LW6SYS_FREE (bt);
@@ -881,7 +886,7 @@ lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
 	  if (level_id <= LW6SYS_LOG_ERROR_ID)
 	    {
 	      va_copy (ap2, ap);
-	      lw6sys_msgbox_alert (level_str, file_only, line, fmt, ap2);
+	      _lw6sys_msgbox_alert (level_str, file_only, line, fmt, ap2);
 	      va_end (ap2);
 	    }
 	}
@@ -924,11 +929,11 @@ lw6sys_log_critical (char *fmt, ...)
   va_end (ap2);
 
   va_copy (ap2, ap);
-  lw6sys_msgbox_alert (_("CRITICAL!"), CRITICAL_FILE, CRITICAL_LINE, fmt,
-		       ap2);
+  _lw6sys_msgbox_alert (_("CRITICAL!"), CRITICAL_FILE, CRITICAL_LINE, fmt,
+			ap2);
   va_end (ap2);
 
-  exit (_LW6SYS_EXIT_CRITICAL);
+  exit (LW6SYS_EXIT_CRITICAL);
 
   va_end (ap);
 }
