@@ -37,6 +37,13 @@
 
 #define _STR_BIN_TEXT_OTHER ".,:;!?()'\"-+*/=_ \t\r\n"
 #define _STR_BIN_TEXT_MIN_PERCENT 75
+#define _STR_RANDOM_WORDS "     0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
+
+typedef struct _join_callback_data_s
+{
+  char *ret;
+  char *glue;
+} _join_callback_data_t;
 
 /**
  * lw6sys_str_copy
@@ -558,6 +565,7 @@ lw6sys_str_reformat (char *str, char *prefix, int nb_columns)
   int i = 0;
   int space_i = 0;
 
+  nb_columns = lw6sys_max (nb_columns, 1);
   str_copy = lw6sys_str_copy (str);
   if (str_copy)
     {
@@ -569,7 +577,7 @@ lw6sys_str_reformat (char *str, char *prefix, int nb_columns)
 	{
 	  if (lw6sys_chr_is_eol (pos[0]))
 	    {
-	      while (lw6sys_chr_is_eol (pos[0]))
+	      while (lw6sys_chr_is_eol (pos[1]))
 		{
 		  pos++;
 		}
@@ -662,6 +670,7 @@ lw6sys_str_reformat_this (char *str, int nb_columns)
   char *pos = NULL;
   char *last_space = NULL;
 
+  nb_columns = lw6sys_max (nb_columns, 1);
   pos = str;
   while (*pos)
     {
@@ -828,6 +837,57 @@ lw6sys_str_split_config_item (char *str)
   return lw6sys_str_split_no_0 (str, ',');
 }
 
+static void
+_join_callback (void *func_data, void *data)
+{
+  _join_callback_data_t *join_callback_data =
+    (_join_callback_data_t *) func_data;
+  char *str = (char *) data;
+  char *tmp = NULL;
+
+  if (join_callback_data->ret)
+    {
+      tmp = join_callback_data->ret;
+      join_callback_data->ret =
+	lw6sys_new_sprintf ("%s%s%s", join_callback_data->ret,
+			    join_callback_data->glue, str);
+      LW6SYS_FREE (tmp);
+    }
+  else
+    {
+      join_callback_data->ret = lw6sys_str_copy (str);
+    }
+}
+
+/**
+ * lw6sys_str_join
+ *
+ * @list: list of strings to join
+ * @glue: string to add in-between
+ *
+ * Companion function of @lw6sys_str_split which will do
+ * the contrary and join the string. Here we use a string
+ * as the glue/separator, more flexible than a simple char
+ * in this case.
+ *
+ * Return value: dynamically allocated string
+ */
+char *
+lw6sys_str_join (lw6sys_list_t * list, char *glue)
+{
+  char *ret = NULL;
+  _join_callback_data_t join_callback_data;
+
+  join_callback_data.ret = ret;
+  join_callback_data.glue = glue;
+
+  lw6sys_list_map (list, _join_callback, &join_callback_data);
+
+  ret = join_callback_data.ret;
+
+  return ret;
+}
+
 /**
  * lw6sys_str_toupper
  *
@@ -917,6 +977,34 @@ lw6sys_str_random (int len)
   return (char *) ret;
 }
 
+/**
+ * lw6sys_str_random_words
+ *
+ * @len: the length of the random string to generate.
+ *
+ * Generates a random string, this is usefull for testing.
+ * This version only generates words with alpha-numerical
+ * content (letters and digits plus spaces).
+ *
+ * Return value: newly allocated string
+ */
+char *
+lw6sys_str_random_words (int len)
+{
+  unsigned char *ret = NULL;
+  int i = 0;
+  int cat_len = strlen (_STR_RANDOM_WORDS);
+
+  ret = (unsigned char *) LW6SYS_MALLOC (len + 1);
+  for (i = 0; i < len; ++i)
+    {
+      ret[i] = _STR_RANDOM_WORDS[lw6sys_random (cat_len)];
+    }
+  ret[len] = 0;
+
+  return (char *) ret;
+}
+
 static int
 _chr_is_text (char c)
 {
