@@ -142,10 +142,13 @@
 #define _ESCAPE_STR_SQL_VALUE "this is a string with a simple quote '' a double quote \" a tab char \" \" and a backslash \"\\\" a lower and greater <> and a few allowed chars _-.,#:;?& OK"
 #define TEST_REFORMAT_STR1 "this is a short string"
 #define TEST_REFORMAT_STR2 "this is a very long string it should be cut in some places but wherever there is a very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very long word it won't be cut.\n\nIt should even handle newlines in some places but well, this is not absolutely necessary"
-#define TEST_REFORMAT_PREFIX "# "
-#define TEST_REFORMAT_COLUMNS 40
+#define TEST_REFORMAT_PREFIX1 "# "
+#define TEST_REFORMAT_COLUMNS1 25
+#define TEST_REFORMAT_PREFIX2 ""
+#define TEST_REFORMAT_COLUMNS2 10
 #define TEST_SPLIT_STR "/foo/bar,/foo/bar"
 #define TEST_SPLIT_CHAR 'o'
+#define TEST_STR_GLUE "-+-"
 #define _TEST_STR_LOWER_UPPER "foObaR!"
 #define _TEST_STR_TRUNCATE 5
 #define _TEST_STR_RANDOM_LEN 1000
@@ -161,7 +164,9 @@
 #define TEST_SORT_STR_MIN "0"
 #define TEST_SORT_STR_MAX "9"
 #define _TEST_SIGNAL_LOOPS 25
+#define _TEST_SIGNAL_TRAP_ERRORS 1
 #define TEST_CONVERT_INT 421
+#define TEST_CONVERT_LONG_LONG 421421421421421
 #define TEST_CONVERT_BOOL 1
 #define TEST_CONVERT_FLOAT 3.14f
 #define TEST_RANDOM_RANGE 1000
@@ -560,6 +565,7 @@ test_convert ()
   {
     char *str;
     int i;
+    int64_t l;
     float f;
 
     str = lw6sys_itoa (TEST_CONVERT_INT);
@@ -579,6 +585,25 @@ test_convert ()
 	ret = 0;
       }
 
+    str = lw6sys_lltoa (TEST_CONVERT_LONG_LONG);
+    if (str)
+      {
+	l = lw6sys_atoll (str);
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _x_ ("long long=%" LW6SYS_PRINTF_LL
+			 "d -> str=\"%s\" -> long long=%" LW6SYS_PRINTF_LL
+			 "d"), TEST_CONVERT_LONG_LONG, str, l);
+	if (l != TEST_CONVERT_LONG_LONG)
+	  {
+	    ret = 0;
+	  }
+	LW6SYS_FREE (str);
+      }
+    else
+      {
+	ret = 0;
+      }
+
     str = lw6sys_btoa (TEST_CONVERT_BOOL);
     if (str)
       {
@@ -2433,7 +2458,7 @@ test_path ()
 		    _FIND_IN_DIR_AND_PATH_PATH, _FIND_IN_DIR_AND_PATH_FILE);
 	LW6SYS_FREE (path);
       }
-    path = lw6sys_file_only (_TEST_PATH_FILE_ONLY);
+    path = lw6sys_path_file_only (_TEST_PATH_FILE_ONLY);
     if (path)
       {
 	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("file only for \"%s\" is \"%s\""),
@@ -2540,9 +2565,11 @@ test_random ()
 
 /*
  * Testing functions in signal.c
+ *
+ * Not declared static so that backtrace is more meaningfull.
  */
-static int
-test_signal ()
+int
+_lw6sys_test_signal (int mode)
 {
   int ret = 1;
   LW6SYS_TEST_FUNCTION_BEGIN;
@@ -2554,7 +2581,7 @@ test_signal ()
       {
 	lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("quit!=0, strange..."));
       }
-    lw6sys_signal_custom ();
+    lw6sys_signal_custom (_TEST_SIGNAL_TRAP_ERRORS);
     lw6sys_log (LW6SYS_LOG_NOTICE,
 		_x_
 		("our own SIGTERM and SIGHUP signals are in place, try typing CTRL+C for instance"));
@@ -2572,6 +2599,11 @@ test_signal ()
     lw6sys_signal_term_handler (0);
     lw6sys_signal_int_handler (0);
     lw6sys_signal_hup_handler (0);
+    if (mode)
+      {
+	lw6sys_signal_segv_handler (0);
+	lw6sys_signal_fpe_handler (0);
+      }
     lw6sys_signal_default ();
   }
 
@@ -2874,8 +2906,8 @@ test_str ()
       && !lw6sys_str_starts_with_no_case (STR_STARTS_WITH,
 					  STR_STARTS_WITH_KO);
     str =
-      lw6sys_str_reformat (TEST_REFORMAT_STR1, TEST_REFORMAT_PREFIX,
-			   TEST_REFORMAT_COLUMNS);
+      lw6sys_str_reformat (TEST_REFORMAT_STR1, TEST_REFORMAT_PREFIX1,
+			   TEST_REFORMAT_COLUMNS2);
     if (str)
       {
 	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("reformatted string is \"%s\""),
@@ -2888,8 +2920,8 @@ test_str ()
       }
 
     str =
-      lw6sys_str_reformat (TEST_REFORMAT_STR2, TEST_REFORMAT_PREFIX,
-			   TEST_REFORMAT_COLUMNS);
+      lw6sys_str_reformat (TEST_REFORMAT_STR2, TEST_REFORMAT_PREFIX2,
+			   TEST_REFORMAT_COLUMNS2);
     if (str)
       {
 	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("reformatted string is \"%s\""),
@@ -2904,7 +2936,7 @@ test_str ()
     str = lw6sys_str_copy (TEST_REFORMAT_STR1);
     if (str)
       {
-	lw6sys_str_reformat_this (str, TEST_REFORMAT_COLUMNS);
+	lw6sys_str_reformat_this (str, TEST_REFORMAT_COLUMNS1);
 	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("reformatted string is \"%s\""),
 		    str);
 	LW6SYS_FREE (str);
@@ -2913,7 +2945,7 @@ test_str ()
     str = lw6sys_str_copy (TEST_REFORMAT_STR2);
     if (str)
       {
-	lw6sys_str_reformat_this (str, TEST_REFORMAT_COLUMNS);
+	lw6sys_str_reformat_this (str, TEST_REFORMAT_COLUMNS2);
 	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("reformatted string is \"%s\""),
 		    str);
 	LW6SYS_FREE (str);
@@ -2923,6 +2955,13 @@ test_str ()
     if (list)
       {
 	lw6sys_list_map (list, str_split_func, NULL);
+	str = lw6sys_str_join (list, TEST_STR_GLUE);
+	if (str)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("joined string is \"%s\""),
+			str);
+	    LW6SYS_FREE (str);
+	  }
 	lw6sys_list_free (list);
       }
 
@@ -2930,6 +2969,13 @@ test_str ()
     if (list)
       {
 	lw6sys_list_map (list, str_split_func, NULL);
+	str = lw6sys_str_join (list, TEST_STR_GLUE);
+	if (str)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("joined string is \"%s\""),
+			str);
+	    LW6SYS_FREE (str);
+	  }
 	lw6sys_list_free (list);
       }
 
@@ -2937,6 +2983,13 @@ test_str ()
     if (list)
       {
 	lw6sys_list_map (list, str_split_func, NULL);
+	str = lw6sys_str_join (list, TEST_STR_GLUE);
+	if (str)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("joined string is \"%s\""),
+			str);
+	    LW6SYS_FREE (str);
+	  }
 	lw6sys_list_free (list);
       }
 
@@ -2975,6 +3028,27 @@ test_str ()
 		    strlen (str), str);
 	LW6SYS_FREE (str);
       }
+    str = lw6sys_str_random_words (_TEST_STR_RANDOM_LEN);
+    if (str)
+      {
+	is_bin = lw6sys_str_is_bin (str, strlen (str));
+	if (!is_bin)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_x_ ("random string not considered binary -> good!"));
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_x_
+			("random string considered binary, this is strange, test isn't reported as failed since an error can always happen and a monkey could random-type a shakespeare masterpice, but still..."));
+	  }
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _x_
+		    ("random string (with alnum words) of %d chars \"%s\""),
+		    strlen (str), str);
+	LW6SYS_FREE (str);
+      }
     str = lw6sys_id_ltoa (lw6sys_generate_id_64 ());
     if (str)
       {
@@ -3788,9 +3862,9 @@ lw6sys_test (int mode)
     && test_log (mode) && test_math () && test_mem () && test_mutex ()
     && test_options () && test_nop () && test_path () && test_progress ()
     && test_random () && test_sdl () && test_serial () && test_shape ()
-    && test_signal () && test_sort () && test_spinlock () && test_str ()
-    && test_stream () && test_thread () && test_time () && test_url ()
-    && test_vthread ();
+    && _lw6sys_test_signal (mode) && test_sort () && test_spinlock ()
+    && test_str () && test_stream () && test_thread () && test_time ()
+    && test_url () && test_vthread ();
 
   return ret;
 }
