@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,29 +28,30 @@
 #include "sys-internal.h"
 
 static void *_run_handler = NULL;
-static _lw6sys_vthread_handler_t *_main_vhandler = NULL;
+static _lw6sys_thread_handler_t *_main_handler = NULL;
 
 static void
-vthread_callback (_lw6sys_vthread_handler_t * vthread_handler)
+_vthread_callback ()
 {
-  _lw6sys_thread_handler_t *thread_handler = &(vthread_handler->thread);
+  _lw6sys_thread_handler_t *tmp_handler = NULL;
 
-  if (thread_handler->callback_join)
+  if (_main_handler->callback_join)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _("begin vthread"));
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("begin vthread"));
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("begin vthread (fast mode, no join)"));
+      lw6sys_log (LW6SYS_LOG_INFO,
+		  _x_ ("begin vthread (fast mode, no join)"));
     }
-  if (thread_handler->callback_func)
+  if (_main_handler->callback_func)
     {
-      thread_handler->callback_func (thread_handler->callback_data);
+      _main_handler->callback_func (_main_handler->callback_data);
     }
   /* 
    * callback is over, we signal it to the caller, if needed
    */
-  thread_handler->callback_done = 1;
+  _main_handler->callback_done = 1;
   /*
    * If callback_join is defined, we wait until the caller
    * has called "join" before freeing the ressources. If it's
@@ -59,32 +60,38 @@ vthread_callback (_lw6sys_vthread_handler_t * vthread_handler)
    * and queried by the caller. If we're running a stateless
    * thread we just end quickly.
    */
-  if (thread_handler->callback_join)
+  if (_main_handler->callback_join)
     {
-      while (!thread_handler->can_join)
+      while (!_main_handler->can_join)
 	{
 	  /*
 	   * Now the caller is supposed to set "can_join"
 	   * to allow this thread to actually finish.
 	   */
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _("waiting for can_join to be 1 (vhtread)"));
-	  lw6sys_idle ();
+	  lw6sys_log (LW6SYS_LOG_INFO,
+		      _x_ ("waiting for can_join to be 1 (vhtread)"));
+	  lw6sys_snooze ();
 	}
-      thread_handler->callback_join (thread_handler->callback_data);
+      /*
+       * In the peculiar case of vthread, join must imperatively
+       * be called in this thread, not in the other one...
+       */
+      _main_handler->callback_join (_main_handler->callback_data);
     }
-  if (thread_handler->callback_join)
+  if (_main_handler->callback_join)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _("end vthread"));
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("end vthread"));
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("end vthread (fast mode, no join)"));
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("end vthread (fast mode, no join)"));
     }
   /* 
    * callback is over, we signal it to the caller, if needed
    */
-  vthread_handler->join_done = 1;
+  tmp_handler = _main_handler;
+  _main_handler = NULL;
+  LW6SYS_FREE (tmp_handler);
 }
 
 /**
@@ -113,60 +120,71 @@ lw6sys_vthread_run (lw6sys_thread_callback_func_t callback_func,
 {
   int ret = 0;
 
-  if (!_main_vhandler)
+  if (!_run_handler && !_main_handler)
     {
       _run_handler =
 	lw6sys_thread_create (callback_func, callback_join, callback_data);
       if (_run_handler)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("run vthread begin"));
-
-	  while (!_main_vhandler)
-	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _
-			  ("waiting for main handler to be defined by spawned thread"));
-	      lw6sys_idle ();
-	    }
-
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _("vthread main handler"));
-	  vthread_callback (_main_vhandler);
+	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("run vthread begin"));
 
+	  /*
+	   * More than one vthread could be started (not at once!)
+	   * successively so we loop until spawned is done.
+	   */
 	  while (!lw6sys_thread_is_callback_done (_run_handler))
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _("waiting for callback to be done (vhtread)"));
-	      lw6sys_idle ();
+	      while (_main_handler == NULL
+		     && !lw6sys_thread_is_callback_done (_run_handler))
+		{
+		  lw6sys_log (LW6SYS_LOG_INFO,
+			      _x_
+			      ("waiting for main handler to be defined by spawned thread"));
+		  lw6sys_snooze ();
+		}
+	      /*
+	       * _main_vandler could be NULL if we're here because
+	       * the callback is done
+	       */
+	      if (_main_handler)
+		{
+		  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("vthread main handler"));
+		  _vthread_callback ();
+		}
+	      lw6sys_log (LW6SYS_LOG_INFO,
+			  _x_ ("waiting for callback to be done (vhtread)"));
+	      lw6sys_snooze ();
 	    }
 
-	  lw6sys_log (LW6SYS_LOG_INFO, _("run vthread end"));
+	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("run vthread end"));
 
 	  lw6sys_thread_join (_run_handler);
 	  _run_handler = NULL;
-
+#if 0
 	  /*
 	   * Only free _main_handler now.
 	   * See https://savannah.gnu.org/bugs/?27819 for details.
 	   * The idea is that we need join_done to join properly.
 	   */
-	  if (_main_vhandler)
+	  if (_main_handler)
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG, _("freeing _main_vhandler"));
+	      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("freeing _main_vhandler"));
 	      LW6SYS_FREE (_main_vhandler);
 	      _main_vhandler = NULL;
 	    }
-
+#endif
 	  ret = 1;
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("unable to create run vthread"));
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _x_ ("unable to create run vthread"));
 	}
     }
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("can't run vthread, already initialized"));
+		  _x_ ("can't run vthread, already initialized"));
     }
 
   return ret;
@@ -215,34 +233,39 @@ lw6sys_vthread_create (lw6sys_thread_callback_func_t callback_func,
 		       void *callback_data)
 {
   int ret = 0;
-  _lw6sys_vthread_handler_t *vhandler = NULL;
-  _lw6sys_thread_handler_t *handler = NULL;
+  _lw6sys_thread_handler_t *tmp_handler = NULL;
 
-  if (!_main_vhandler)
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("vthread_create"));
+  if (!_main_handler)
     {
-      vhandler = (_lw6sys_vthread_handler_t *)
-	LW6SYS_CALLOC (sizeof (_lw6sys_vthread_handler_t));
-      if (vhandler)
+      tmp_handler =
+	(_lw6sys_thread_handler_t *)
+	LW6SYS_CALLOC (sizeof (_lw6sys_thread_handler_t));
+      if (tmp_handler)
 	{
-	  handler = &(vhandler->thread);
 	  // handler->thread member should stay O/NULL
-	  handler->id = _LW6SYS_VTHREAD_ID;
-	  handler->callback_func = callback_func;
-	  handler->callback_join = callback_join;
-	  handler->callback_data = callback_data;
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _("vhtread create successfull"));
+	  tmp_handler->id = _LW6SYS_VTHREAD_ID;
+	  tmp_handler->callback_func = callback_func;
+	  tmp_handler->callback_join = callback_join;
+	  tmp_handler->callback_data = callback_data;
+	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("vhtread create successfull"));
 	  ret = 1;
-	  _main_vhandler = vhandler;
+	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("defining _main_handler"));
+	  /*
+	   * It's important to only affect in now that 
+	   * all fields are correctly filled.
+	   */
+	  _main_handler = tmp_handler;
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("can't create vthread"));
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("can't create vthread"));
 	}
     }
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _
+		  _x_
 		  ("can't start vthread, there's already a running vthread"));
     }
 
@@ -262,35 +285,30 @@ lw6sys_vthread_create (lw6sys_thread_callback_func_t callback_func,
 void
 lw6sys_vthread_join ()
 {
-  _lw6sys_vthread_handler_t *vhandler = NULL;
-  _lw6sys_thread_handler_t *handler = NULL;
-
-  vhandler = _main_vhandler;
-  if (vhandler)
+  if (_main_handler)
     {
-      handler = &(vhandler->thread);
-      if (handler->callback_join)
+      if (_main_handler->callback_join)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("joining vthread"));
+	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("joining vthread"));
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _("joining vthread (fast mode, no join)"));
+	  lw6sys_log (LW6SYS_LOG_INFO,
+		      _x_ ("joining vthread (fast mode, no join)"));
 	}
 
-      handler->can_join = 1;
+      _main_handler->can_join = 1;
 
-      while (!vhandler->join_done)
+      while (_main_handler)
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _("waiting for join to be done (vhtread)"));
-	  lw6sys_idle ();
+	  lw6sys_log (LW6SYS_LOG_INFO,
+		      _x_ ("waiting for _main_handler to be NULL"));
+	  lw6sys_snooze ();
 	}
     }
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("can't call join vthread, vhandler is NULL"));
+		  _x_ ("can't call join vthread, vhandler is NULL"));
     }
 }
