@@ -55,6 +55,7 @@
 /*
  * Those are so common it saves time to always include them
  */
+#include <limits.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -106,6 +107,10 @@ typedef char *char_ptr_t;
 #define LW6SYS_SLEEP_DELAY 1
 #define LW6SYS_SNOOZE_DELAY 100
 
+#define LW6SYS_EXIT_OK 0
+#define LW6SYS_EXIT_ERROR 1
+#define LW6SYS_EXIT_CRITICAL 2
+
 /*
  * Yet another MS-windows hack, printf %ll doesn't work
  * one needs to use a special "%I64" instead...
@@ -137,6 +142,9 @@ typedef char *char_ptr_t;
 
 #define LW6SYS_TEST_OUTPUT { if (ret) { lw6sys_log(LW6SYS_LOG_NOTICE,_("test SUCCESSFULL!")); } else { lw6sys_log(LW6SYS_LOG_WARNING,_("test FAILED...")); } }
 
+#define LW6SYS_BUILD_ENABLE_YES "yes"
+#define LW6SYS_BUILD_ENABLE_NO "no"
+
 typedef struct lw6sys_xyz_s
 {
   /*
@@ -430,7 +438,8 @@ extern char *lw6sys_build_get_stamp ();
 extern char *lw6sys_build_get_md5sum ();
 extern char *lw6sys_build_get_copyright ();
 extern char *lw6sys_build_get_license ();
-extern char *lw6sys_build_get_url ();
+extern char *lw6sys_build_get_home_url ();
+extern char *lw6sys_build_get_bugs_url ();
 extern char *lw6sys_build_get_configure_args ();
 extern char *lw6sys_build_get_gcc_version ();
 extern char *lw6sys_build_get_cflags ();
@@ -443,6 +452,8 @@ extern char *lw6sys_build_get_endianness ();
 extern int lw6sys_build_get_pointer_size ();
 extern int lw6sys_build_is_x86 ();
 extern char *lw6sys_build_get_host_os ();
+extern int lw6sys_build_is_gnu ();
+extern int lw6sys_build_is_unix ();
 extern int lw6sys_build_is_ms_windows ();
 extern int lw6sys_build_is_mac_os_x ();
 extern int lw6sys_build_is_gp2x ();
@@ -550,9 +561,11 @@ extern void lw6sys_color_f_solid (lw6sys_color_f_t * color);
 
 /* sys-convert.c */
 extern int lw6sys_atoi (char *str);
+extern int64_t lw6sys_atoll (char *str);
 extern int lw6sys_atob (char *str);
 extern float lw6sys_atof (char *str);
 extern char *lw6sys_itoa (int value);
+extern char *lw6sys_lltoa (int64_t value);
 extern char *lw6sys_btoa (int value);
 extern char *lw6sys_ftoa (float value);
 
@@ -784,6 +797,9 @@ extern int lw6sys_check_mutex_count ();
 extern int lw6sys_true ();
 extern int lw6sys_false ();
 
+/* sys-openmp.c */
+extern int lw6sys_openmp_get_num_procs ();
+
 /* sys-options.c */
 extern char *lw6sys_get_cwd ();
 extern char *lw6sys_get_default_user_dir ();
@@ -821,7 +837,7 @@ extern char *lw6sys_path_add_slash (char *path);
 extern char *lw6sys_path_strip_slash (char *path);
 extern char *lw6sys_path_concat (char *path1, char *path2);
 extern lw6sys_list_t *lw6sys_path_split (char *path);
-extern char *lw6sys_file_only (char *path);
+extern char *lw6sys_path_file_only (char *path);
 extern int lw6sys_path_is_relative (char *path);
 extern int lw6sys_path_is_cwd (char *path);
 extern char *lw6sys_path_parent (char *path);
@@ -897,11 +913,13 @@ extern int lw6sys_shape_is_same_xy (lw6sys_whd_t * shape_a,
 				    lw6sys_whd_t * shape_b);
 
 /* sys-signal.c */
-extern void lw6sys_signal_custom ();
+extern void lw6sys_signal_custom (int trap_errors);
 extern void lw6sys_signal_default ();
 extern void lw6sys_signal_term_handler (int signum);
 extern void lw6sys_signal_int_handler (int signum);
 extern void lw6sys_signal_hup_handler (int signum);
+extern void lw6sys_signal_segv_handler (int signum);
+extern void lw6sys_signal_fpe_handler (int signum);
 extern void lw6sys_signal_send_quit ();
 extern int lw6sys_signal_poll_quit ();
 
@@ -949,10 +967,12 @@ extern char *lw6sys_eol ();
 extern lw6sys_list_t *lw6sys_str_split (char *str, char c);
 extern lw6sys_list_t *lw6sys_str_split_no_0 (char *str, char c);
 extern lw6sys_list_t *lw6sys_str_split_config_item (char *str);
+extern char *lw6sys_str_join (lw6sys_list_t * list, char *glue);
 extern void lw6sys_str_toupper (char *str);
 extern void lw6sys_str_tolower (char *str);
 extern void lw6sys_str_truncate (char *str, int len);
 extern char *lw6sys_str_random (int len);
+extern char *lw6sys_str_random_words (int len);
 extern int lw6sys_str_is_bin (char *buf, int len);
 
 /* sys-stream.c */
